@@ -37,7 +37,8 @@ class AutoBindingGrammar:
 
 	* type: a name of a symbol that should have nodeClass.fromParseResult
 	  as a parse action.
-	* bindings: as type, but a list of symbol names
+	* bindings: as type, but a list of symbol names; when bindings is
+	  present, type is ignored.
 	* parseActionFor: that's a list of symbol names the "node" (which more
 	  likely is just some function) must be called for as a parse action.
 	* collapsible: if set on a node class, the parse action will be
