@@ -56,18 +56,20 @@ class FieldInfos(object):
 			name is not unique.  Column names are normalized by lowercasing here
 			(which, however, does not affect L{utils.QuotedName}s).
 
-	A FieldInfos object is instanciated with the object it will annotate,
+	A FieldInfos object is instantiated with the object it will annotate,
 	and the annotation (i.e., setting of the fieldInfos attribute on
-	the parent) will happen during instanciation.
+	the parent) will happen during instantiation.
 	"""
 	def __init__(self, parent, context):
 		self.seq, self.columns = [], {}
 		self.parent = weakref.proxy(parent)
-		parent.fieldInfos = self
 
 	def __repr__(self):
 		return "<Column information %s>"%(repr(self.seq))
 
+	def __iter__(self):
+		return iter(self.seq)
+
 	def locateTable(self, refName):
 		"""returns a table instance matching the node.TableName refName.
 
@@ -138,13 +140,21 @@ class FieldInfos(object):
 					" have differing names.  First differing name: %s vs. %s"%(
 						ownCol[0], otherCol[0]))
 
+	def copy(self, newParent):
+		"""returns a deep copy self, parented to newParent.
+		"""
+		newFI = FieldInfos(newParent, None)
+		for label, info in self:
+			newFI.addColumn(label, info.change())
+		return newFI
 
+	
 class TableFieldInfos(FieldInfos):
 	"""FieldInfos coming from something that's basically a table in the DB.
 
 	This includes joins.
 
-	To instanciate those, use the makeForNode class method below.
+	To instantiate those, use the makeForNode class method below.
 	"""
 	def __init__(self, parent, context):
 		FieldInfos.__init__(self, parent, context)
@@ -201,7 +211,7 @@ def _annotateNodeRecurse(node, context):
 class QueryFieldInfos(FieldInfos):
 	"""FieldInfos inferred from a FROM clause.
 
-	To instanciate those, use the makeForNode class method below.
+	To instantiate those, use the makeForNode class method below.
 	"""
 
 	# enclosingQuery is set non-None when a whereClause is found in the
