@@ -489,9 +489,24 @@ def _morphTimestamp(node, state):
 	return "(%s)::TIMESTAMP"%flatten(node.args[0])
 
 
+class _PQAggregatedArray(nodes.TransparentMixin, nodes.FieldInfoedNode):
+	type = "_morphedArrayMap"
+
+
+def _morphArrayMap(node, state):
+	# for now, we blindly serialise the expression (arg 1) into our new tree.
+	return _PQAggregatedArray(children=[
+		'(SELECT array_agg(',
+		node.args[0],
+		') from unnest(',
+		node.args[1],
+		') x)'])
+
+
 _miscMorphers = {
 	"numericValueFunction": _adqlFunctionToPG,
 	"timestampFunction": _morphTimestamp,
+	"arrayMapFunction": _morphArrayMap
 }
 
 
@@ -515,7 +530,7 @@ class _PGSC(nodes.SelectNoParens):
 class _PGQS(nodes.ADQLNode):
 	"""A wrapper for a postgres query specification.  
 	
-	The only funciton here is to make sure there's just one LIMIT part
+	The only function here is to make sure there's just one LIMIT part
 	at the very end (except, of course, in deeper subqueries).
 
 	Nuking operand setLimits is already performed by _fixSetLimit below.
@@ -577,7 +592,8 @@ def _forceAlias(node, state):
 			node.alias = node.name
 		return node
 
-	if not isinstance(node.expr, nodes.ColumnReference) and node.alias is None:
+	if not isinstance(node.expr, nodes._BaseColumnReference
+			) and node.alias is None:
 		node.alias = node.name
 	return node
 
@@ -596,7 +612,7 @@ def _fixSetLimit(node, state):
 
 @functools.lru_cache(None)
 def _needsMaterialization():
-	"""returns True if CTEs need to be explitly materialised on our
+	"""returns True if CTEs need to be explicitly materialised on our
 	current server to make them planner barriers.
 	"""
 	from gavo import base
