@@ -42,7 +42,9 @@ def userFunction(name,
 		returntype="double precision", 
 		unit="", 
 		ucd="",
-		polymorphism=()):
+		polymorphism=(),
+		additionalNames=[],
+		depends=None):
 	"""a decorator adding some metadata to python functions to make
 	them suitable as ADQL user defined functions.
 
@@ -64,7 +66,18 @@ def userFunction(name,
 	(signature, documentation) for alternative signatures of the
 	UDF.
 
-	The python function receives an array of arguments; this will in
+	additionalNames, if given, is a list of names the function can
+	also be used as.  This is intended for when you started with 
+	gavo_somefunc and then want to move on to ivo_somefunc without
+	functional change and want to keep legacy queries working.
+
+	depends if non-None, is a name of a postgres function that this UDF
+	needs.  This is for when UDF should disappear when an extension is
+	missing.  This is not evaluated right away because we do not have
+	a database connection during import.  Host code has to arrange
+	for calling cleanForConn(conn).
+
+	The python function receives a list of arguments; this will in
 	general be ADQL expression trees.  It must return either 
 	
 	* a string that will go literally into the eventual serialised SQL 
@@ -87,10 +100,15 @@ def userFunction(name,
 		f.adqlUDF_returntype = returntype
 		f.adqlUDF_unit = unit
 		f.adqlUDF_ucd = ucd
+		f.adqlUDF_depends = depends
 		f.adqlUDF_additionalSignatures = [
 				{"signature": f.adqlUDF_name+signature.strip(), "doc": doc}
 			for signature, doc in polymorphism]
+
 		UFUNC_REGISTRY[f.adqlUDF_name.upper()] = f
+		for alias in additionalNames:
+			UFUNC_REGISTRY[alias.upper()] = f
+
 		return f
 	return deco
 
@@ -113,7 +131,6 @@ def _makeBooleanizer(funcName, booleanExpr):
 	morphhelpers.registerBooleanizer(funcName.upper(), _booleanizeThis)
 
 
-
 @userFunction("gavo_match",
 	"(pattern TEXT, string TEXT) -> INTEGER",
 	"""
@@ -157,7 +174,7 @@ _makeBooleanizer("ivo_hasword",
 	ADQL.
 
 	On this site, this is actually implemented using python's and SQL's
-	LOWER, so for everything except ASCII, your milage will vary.
+	LOWER, so for everything except ASCII, your mileage will vary.
 	""",
 	"integer")
 def _nocasematch(args):
@@ -255,15 +272,18 @@ def _to_jd(args):
 	return "ts_to_jd(%s)"%nodes.flatten(args[0])
 
 
-def _get_histogram_ucd(args):
-	baseUCD = args[0].fieldInfo.ucd
-	if baseUCD:
-		return "stat.histogram;"+baseUCD
-	else:
-		return "stat.histogram"
+class HistogramNode(nodes.FunctionNode):
+	def addFieldInfo(self, context):
+		ucd = "stat.histogram"
+		baseUCD = self.args[0].fieldInfo.ucd
+		if baseUCD:
+			ucd = f"{ucd};{baseUCD}"
+
+		self.fieldInfo = fieldinfo.FieldInfo("integer[]",
+			"", ucd, *nodes.collectUserData(self._getInfoChildren()))
 
 
-@userFunction("gavo_histogram",
+@userFunction("ivo_histogram",
 	"(val REAL, lower REAL, upper REAL, nbins INTEGER) -> INTEGER[]",
 	"""
 	The aggregate function returns a histogram of val with nbins+2 elements.
@@ -275,14 +295,15 @@ def _get_histogram_ucd(args):
 	the TAP response.
 	""",
 	returntype="integer[]",
-	ucd=_get_histogram_ucd)
-def _gavo_histogram(args):
+	additionalNames=["gavo_histogram"])
+def _ivo_histogram(args):
 	if len(args)!=4:
 		raise common.UfuncError(
-			"gavo_histogram takes exactly four arguments (the column to aggregate,"
+			"ivo_histogram takes exactly four arguments (the column to aggregate,"
 			" a lower and upper limit of values to tabulate, and the number"
 			" of bins desired).")
-	return None
+	raise nodes.ReplaceNode(
+		HistogramNode(funName="GAVO_HISTOGRAM", args=args))
 
 
 @userFunction("gavo_ipix",
@@ -295,7 +316,8 @@ def _gavo_histogram(args):
 	PPMXL ids.
 	""",
 	returntype="bigint",
-	ucd="pos")
+	ucd="pos",
+	depends="q3c_ang2ipix")
 def _gavo_ipix(args):
 	if len(args)!=2:
 		raise common.UfuncError(
@@ -312,14 +334,19 @@ class _TransformNode(nodes.FunctionNode):
 	"""
 	name = "gavo_transform"
 	_a_trans = None
+	_a_toSys = None
+
+	ucdMap = {
+		'ICRS': "pos.eq",
+		'FK5': "pos.eq",
+		'FK4': "pos.eq",
+		'GALACTIC': "pos.galactic",
+	}
 
 	def flatten(self):
 		return "(%s)%s"%(nodes.flatten(self.args[0]), self.trans)
 	
-	def addFieldInfos(self, context):
-		# if our argument is properly annotated, that annotation applies
-		# to us as well (though it doesn't quite, with pos.eq vs. pos.galactic;
-		# sucks, but sucks with UCDs).  If it's not, we're basically hosed.
+	def addFieldInfo(self, context):
 		if hasattr(self.args[0], "fieldInfo"):
 			self.fieldInfo = self.args[0].fieldInfo
 
@@ -327,7 +354,13 @@ class _TransformNode(nodes.FunctionNode):
 			# go for an STC-S string
 			self.fieldInfo = fieldinfo.FieldInfo("text", "", "", tainted=True)
 			self.fieldInfo.properties["xtype"] = "adql:REGION"
-				
+
+		# We discard the existing UCD, as that may change depending on the
+		# the frame.  We should probably look at the type, too, and not
+		# call circles, polygons, or MOCs positions.  Let's see when we want
+		# that.
+		self.fieldInfo.ucd = self.ucdMap.get(self.toSys, "pos")
+
 
 @userFunction("gavo_transform",
 	"(from_sys TEXT, to_sys TEXT, geo GEOMETRY) -> GEOMETRY",
@@ -369,7 +402,8 @@ def _gavo_transform(args):
 		raise nodes.ReplaceNode(_TransformNode(
 			funName="gavo_transform", 
 			args=(args[2],),
-			trans=trans))
+			trans=trans,
+			toSys=toSys))
 
 
 @userFunction("gavo_normal_random",
@@ -380,7 +414,7 @@ def _gavo_transform(args):
 	Implementation note: Right now, the Gaussian is approximated by
 	summing up and scaling ten calls to random.  This, hence, is not
 	very precise or fast.  It might work for some use cases, and we
-	will provide a better implemenation if this proves inadequate.
+	will provide a better implementation if this proves inadequate.
 	""",
 	returntype="real")
 def _gavo_normal_random(args):
@@ -397,7 +431,8 @@ def _gavo_normal_random(args):
 	"(moc1 MOC, moc2 MOC) -> MOC",
 	"""returns the union of two MOCs.
 	""",
-	returntype="smoc")
+	returntype="smoc",
+	depends="smoc_union")
 def _gavo_mocunion(args):
 	if len(args)!=2:
 		raise common.UfuncError(
@@ -412,7 +447,8 @@ def _gavo_mocunion(args):
 	"(moc1 MOC, moc2 MOC) -> MOC",
 	"""returns the intersection of two MOCs.
 	""",
-	returntype="smoc")
+	returntype="smoc",
+	depends="smoc_union")
 def _gavo_mocintersect(args):
 	if len(args)!=2:
 		raise common.UfuncError(
@@ -437,8 +473,8 @@ def _string_agg(args):
 		nodes.flatten(args[0]), nodes.flatten(args[1]))
 
 
-@userFunction("ivo_apply_pm",
-	"(ra DOUBLE PRECISION, dec DOUBLE PRECISION, pmra DOUBLE PRECISION, pmde DOUBLE PRECISON, epdist DOUBLE PRECISION) -> POINT",
+@userFunction("gavo_apply_pm",
+	"(ra DOUBLE PRECISION, dec DOUBLE PRECISION, pmra DOUBLE PRECISION, pmde DOUBLE PRECISION, epdist DOUBLE PRECISION) -> POINT",
 	"""Returns a POINT (in the UNDEFINED reference frame) for the position
 	an object at ra/dec with proper motion pmra/pmde has after epdist years.
 
@@ -449,9 +485,20 @@ def _string_agg(args):
 	This function goes through the tangential plane.  Since it does not have
 	information on distance and radial velocity, it cannot reconstruct
 	the true space motion, and hence its results will degrade over time.
+
+	This function should not be used in new queries; use ivo_epoch_prop
+	instead.
 	""",
-	returntype="spoint")
-def _ivo_apply_pm(args):
+	returntype="spoint",
+	additionalNames=["ivo_apply_pm"],
+	depends="epoch_prop")
+def _gavo_apply_pm(args):
+	# we need to make sure we eventually flatten to ivo_apply_pm, as
+	# that's what is defined in //adql.  For that, we have to manipulate
+	# our node, which UserFunction below somwhat stupidly does not allow.
+	# We simply steal its self:
+	utils.stealVar("self").funName = "IVO_APPLY_PM"
+
 	if len(args)==5:
 		# there's no indexing or anything to gain here; drop through to an
 		# implementation in the database.
@@ -465,14 +512,121 @@ def _ivo_apply_pm(args):
 		return None
 	else:
 		raise common.UfuncError(
-			"ivo_apply_pm requires exactly ra, dec, pmra, pmdec, epdist.")
+			"gavo_apply_pm requires exactly ra, dec, pmra, pmdec, epdist.")
 
+
+# epoch_prop will bomb out at the postgres level unless you have a very
+# new pgsphere as of 2022 (actually, it's just a PR at this point).
+
+@userFunction("ivo_epoch_prop",
+	"(ra DOUBLE PRECISION, dec DOUBLE PRECISION, parallax DOUBLE PRECISION,"
+	" pmra DOUBLE PRECISION, pmdec DOUBLE PRECISION,"
+	" radial_velocity DOUBLE PRECISION,"
+	" ref_epoch DOUBLE PRECISION, out_epoch DOUBLE PRECISION)"
+	" -> DOUBLE PRECISION[6]",
+	"""Returns a 6-vector of (ra, dec, parallax, pmra, pmdec, rv)
+	at out_epoch for these quantities at ref_epoch.
+
+	Essentially, it will apply the proper motion under the assumption of
+	linear motion.  Despite the name of the positional parameters, this is 
+	not restricted to equatorial systems, as long as positions and proper
+	motions are expressed in the same reference frames.
+
+	Units on input and output are degrees for ra and dec, mas for parallax,
+	mas/yr for pmra and pmdec, and km/s for the radial velocity.
+
+	ref_epoch and out_epoch are given in Julian years.
+
+	parallax, pmra, pmdec, and radial_velocity may be None and will enter
+	the computations as 0 then, except in the case of parallax, which
+	will be some small value.  When abs(parallax) is smaller or equal
+	to that small value, parallax and radial velocity will be NULL on
+	output.
+
+	In daily use, you probably want to use the ivo_epoch_prop_pos functions.
+	""",
+	returntype="double precision[6]",
+	depends="epoch_prop")
+def _epoch_prop(args):
+	if len(args)!=8:
+		raise common.UfuncError("ivo_epoch_prop gets ra, dec [deg], parallax"
+			" [mas], pmra, pmdec [mas/yr], radial_velocity [km/s], ref_epoch,"
+			" out_epoch [yr] arguments")
+	else:
+		return ("(SELECT array[DEGREES(t[1]), DEGREES(t[2]), t[3],"
+			" DEGREES(t[4]*3.6e6), DEGREES(t[5]*3.6e6), t[6]] FROM"
+			" epoch_prop(spoint(RADIANS({ra}), RADIANS({dec})),"
+			" {parallax}, RADIANS(({pmra})/3.6e6), RADIANS(({pmdec})/3.6e6),"
+			" {radial_velocity}, ({out_epoch})-({ref_epoch})) as t)".format(
+			ra=nodes.flatten(args[0]),
+			dec=nodes.flatten(args[1]),
+			parallax=nodes.flatten(args[2]),
+			pmra=nodes.flatten(args[3]),
+			pmdec=nodes.flatten(args[4]),
+			radial_velocity=nodes.flatten(args[5]),
+			ref_epoch=nodes.flatten(args[6]),
+			out_epoch=nodes.flatten(args[7])))
+
+@userFunction("ivo_epoch_prop_pos",
+	"(ra DOUBLE PRECISION, dec DOUBLE PRECISION, parallax DOUBLE PRECISION,"
+	" pmra DOUBLE PRECISION, pmdec DOUBLE PRECISION,"
+	" radial_velocity DOUBLE PRECISION,"
+	" ref_epoch DOUBLE PRECISION, out_epoch DOUBLE PRECISION)"
+	" -> POINT",
+	"""Returns a POINT giving the position at out_epoch for an object
+	with the six parameters at ref_epoch.
+
+	Essentially, it will apply the proper motion under the assumption of
+	linear motion.  Despite the name of the positional parameters, this is 
+	not restricted to equatorial systems, as long as positions and proper
+	motions are expressed in the same reference frames.
+
+	Units on input are degrees for ra and dec, mas for parallax,
+	mas/yr for pmra and pmdec, and km/s for the radial velocity.
+	ref_epoch and out_epoch are given in Julian years.
+
+	parallax, pmra, pmdec, and radial_velocity may be None and will enter
+	the computations as 0 then, except in the case of parallax, which
+	will be some small value.
+	""",
+	returntype="spoint",
+	polymorphism=[
+		("(ra DOUBLE PRECISION, dec DOUBLE PRECISION," 
+			" pmra DOUBLE PRECISION, pmdec DOUBLE PRECISION,"
+			" ref_epoch DOUBLE PRECISION, out_epoch DOUBLE PRECISION)"
+			" -> POINT",
+		"""A variant of ivo_epoch_prop_pos that behave as if parallax
+		and radial_velocity were both passed as NULL.""")],
+	ucd="pos",
+	depends="epoch_prop")
+def _epoch_prop_pos(args):
+	if len(args)==6:
+		kws = dict((label, nodes.flatten(args[ind]))
+			for ind, label in enumerate(
+				"ra dec pmra pmdec ref_epoch out_epoch".split()))
+		kws["parallax"] = kws["radial_velocity"] = "NULL"
 	
+	elif len(args)==8:
+		kws = dict((label, nodes.flatten(args[ind]))
+			for ind, label in enumerate(
+				"ra dec parallax pmra pmdec radial_velocity ref_epoch out_epoch"
+				.split()))
+
+	else:
+		raise common.UfuncError("ivo_epoch_prop_pos gets ra, dec [deg], parallax"
+			" [mas], pmra, pmdec [mas/yr], radial_velocity [km/s], ref_epoch,"
+			" out_epoch [yr] arguments, where you may leave out parallax and"
+			" radial_velocity.")
+
+	return ("(SELECT spoint(t[1], t[2]) FROM"
+		" epoch_prop(spoint(RADIANS({ra}), RADIANS({dec})),"
+		" {parallax}, RADIANS(({pmra})/3.6e6), RADIANS(({pmdec})/3.6e6),"
+		" {radial_velocity}, ({out_epoch})-({ref_epoch})) as t)"
+		.format(**kws))
 
 
-# the healpix functions are currently available in a pgsphere fork
-# on credativ's github area, and there are debian packages in
-# GAVO's repo.  We'd hope there'll be a stable backport in late 2020.
+# the healpix functions require a fairly recent pgspsphere (available
+# as of Debian bullseye)
 
 @userFunction("ivo_healpix_index",
 	"(order INTEGER, ra DOUBLE PRECISION, dec DOUBLE PRECISION) -> BIGINT",
@@ -485,7 +639,8 @@ def _ivo_apply_pm(args):
 
 	is also available.
 	""",
-	returntype="bigint")
+	returntype="bigint",
+	depends="healpix_nest")
 def _ivo_healpix_index(args):
 	if len(args)==2:
 		return "healpix_nest(%s, %s)"%(
@@ -503,7 +658,8 @@ def _ivo_healpix_index(args):
 	"""returns a POINT corresponding to the center of the healpix with
 	the given index at the given order.
 	""",
-	returntype="spoint")
+	returntype="spoint",
+	depends="healpix_nest")
 def _ivo_healpix_center(args):
 	if len(args)!=2:
 		raise common.UfuncError("ivo_healpix_center only takes (index, order)"
@@ -678,7 +834,8 @@ class _SpecconvNode(nodes.FieldInfoedNode):
 		
 		Clearly, overriding known units is likely to yield bad results;
 		the translator therefore warns if an existing unit is overridden
-		with a different unit.""")])
+		with a different unit.""")],
+	additionalNames=["ivo_specconv"])
 def _gavo_specconv(args):
 	try:
 		if len(args)==2:
@@ -696,7 +853,7 @@ def _gavo_specconv(args):
 		raise common.UfuncError(msg)
 
 	raise nodes.ReplaceNode(newNode)
-	
+
 
 class UserFunction(nodes.FunctionNode):
 	"""A node processing user defined functions.
@@ -738,3 +895,22 @@ class UserFunction(nodes.FunctionNode):
 
 
 nodes.registerNode(UserFunction)
+
+
+def _cleanForConn(conn):
+	"""removes UDFs requiring postgres functions not available in what conn
+	points to.
+
+	This is run once during database initialisation.
+	"""
+	toRemove = set()
+	for name, funcDef in UFUNC_REGISTRY.items():
+		if funcDef.adqlUDF_depends:
+			if funcDef.adqlUDF_depends not in conn.extensionFunctions:
+				toRemove.add(name)
+	
+	for name in toRemove:
+		del UFUNC_REGISTRY[name]
+
+
+base.onDBInit(_cleanForConn)
