@@ -79,7 +79,8 @@ from gavo.base.sqlsupport import (getDBConnection,
 	setDBMeta, getDBMeta,
 	getPgVersion,
 	NUMERIC_TYPES, ORDERED_TYPES,
-	NonBlockingQuery)
+	NonBlockingQuery,
+	onDBInit)
 
 from gavo.base.structure import (Structure, ParseableStructure, 
 	DataContent, makeStruct, RestrictionMixin)
@@ -94,7 +95,7 @@ from gavo.base.sqlmunge import (getSQLForField, getSQLKey,
 
 from gavo.base.unitconv import (
 	computeConversionFactor, parseUnit, computeColumnConversions,
-	getSpecExpr,
+	getSpecExpr, getSpecConverter,
 	IncompatibleUnits, BadUnit, 
 	LIGHT_C, PLANCK_H, BOLTZMANN_K)
 
