@@ -17,6 +17,9 @@ if you write::
 foo contains not a loop element but whatever that spit out.  In particular,
 macros within the loop are expanded not within some FEED element but
 within the RD.
+
+There is a non-expanding version of STREAM, too, but that has to take
+special precautions.
 """
 
 #c Copyright 2008-2022, the GAVO project <gavo@ari.uni-heidelberg.de>
@@ -29,6 +32,7 @@ import csv
 import re
 from io import StringIO
 
+from gavo import base # (to pass into codeItems' namespaces only
 from gavo import utils
 from gavo.base import attrdef
 from gavo.base import common
@@ -70,7 +74,7 @@ class ActiveTag(object):
 	name_ = None
 
 
-class GhostMixin(object):
+class GhostMixin(common.StructCallbacks):
 	"""A mixin to make a Structure ghostly.
 	
 	Most active tags are "ghostly", i.e., the do not (directly)
@@ -79,7 +83,7 @@ class GhostMixin(object):
 	the Structure's ``end_`` method to not feed us to the parent.
 	"""
 	def onElementComplete(self):
-		self._onElementCompleteNext(GhostMixin)
+		super().onElementComplete()
 		raise common.Ignore(self)
 
 
@@ -535,7 +539,7 @@ class ReplayedEventsWithFreeAttributesBase(DelayedReplayBase):
 			for key, value in self.source.DEFAULTS.defaults.items():
 				if not hasattr(self, "macro_"+key):
 					setattr(self, "macro_"+key, lambda v=value: v)
-		self._completeElementNext(ReplayedEventsWithFreeAttributesBase, ctx)
+		super().completeElement(ctx)
 
 	def getAttribute(self, name):
 		try:
@@ -564,7 +568,7 @@ class ReplayedEvents(ReplayedEventsWithFreeAttributesBase):
 	name_ = "FEED"
 
 	def completeElement(self, ctx):
-		self._completeElementNext(ReplayedEvents, ctx)
+		super().completeElement(ctx)
 		self._replayer()
 
 
@@ -590,7 +594,10 @@ class GeneratorAttribute(attrdef.UnicodeAttribute):
 			"  ", governingLine=1)
 		src = "def makeRows(context):\n"+src+"\n"
 		instance.iterRowsFromCode = utils.compileFunction(
-			src, "makeRows", useGlobals={"definitionContext": ctx})
+			src, "makeRows", useGlobals={
+				"definitionContext": ctx, 
+				"utils": utils,
+				"base": base})
 
 
 class Loop(ReplayedEventsWithFreeAttributesBase):
@@ -610,7 +617,9 @@ class Loop(ReplayedEventsWithFreeAttributesBase):
 		description="A python generator body that yields dictionaries"
 		" that are then used as loop items.  You can access the parse context"
 		" as the context variable in these code snippets.  context.replayTarget"
-		" is the struct the loop is feeding to.", strip=False)
+		" is the struct the loop is feeding to.  You also get the utils and base"
+		" namespaces, though using them it *a bit* dangerous (we don't guarantee"
+		" their stability).", strip=False)
 
 	def maybeExpand(self, val):
 		if "\\" in val:
@@ -654,7 +663,7 @@ class Loop(ReplayedEventsWithFreeAttributesBase):
 		return rowIterators[0]
 			
 	def completeElement(self, ctx):
-		self._completeElementNext(Loop, ctx)
+		super().completeElement(ctx)
 		for row in self._getRowIterator(ctx):
 			for name, value in row.items():
 				if value:
