@@ -214,7 +214,7 @@ def getWCS(wcsFields, naxis=(1,2), relax=True):
 
 
 def pix2foc(wcsFields, pixels):
-	"""returns the focal plane coordindates for the 2-sequence pixels.
+	"""returns the focal plane coordinates for the 2-sequence pixels.
 
 	(this is a thin wrapper intended to abstract for pix2world's funky
 	calling convention; also, we fix on the silly "0 pixel is 1 convention")
@@ -225,7 +225,7 @@ def pix2foc(wcsFields, pixels):
 
 
 def pix2sky(wcsFields, pixels):
-	"""returns the sky coordindates for the 2-sequence pixels.
+	"""returns the sky coordinates for the 2-sequence pixels.
 
 	(this is a thin wrapper intended to abstract for pix2world's funky
 	calling convention; also, we fix on the silly "0 pixel is 1 convention")
@@ -236,7 +236,7 @@ def pix2sky(wcsFields, pixels):
 
 
 def sky2pix(wcsFields, longLat):
-	"""returns the pixel coordindates for the 2-sequence longLad.
+	"""returns the pixel coordinates for the 2-sequence longLad.
 
 	(this is a thin wrapper intended to abstract for world2pix's funky
 	calling convention; also, we fix on the silly "0 pixel is 1 convention")
