@@ -421,7 +421,7 @@ class MetaAttribute(attrdef.AttributeDef):
 class MetaMixin(common.StructCallbacks):
 	"""is a mixin for entities carrying meta information.
 
-	The meta mixin provides the followng methods:
+	The meta mixin provides the following methods:
 
 		- setMetaParent(m) -- sets the name of the meta container enclosing the
 			current one.  m has to have the Meta mixin as well.
@@ -439,7 +439,7 @@ class MetaMixin(common.StructCallbacks):
 	well (propagate=True).
 
 	Metadata is not copied when the embedding object is copied.
-	That, frankly, has not been a good design descision, and there should
+	That, frankly, has not been a good design decision, and there should
 	probably be a way to pass copypable=True to the mixin's attribute
 	definition.
 	"""
@@ -749,7 +749,7 @@ class ComputedMetaMixin(MetaMixin):
 
 
 class MetaItem(object):
-	"""is a collection of homogenous MetaValues.
+	"""is a collection of homogeneous MetaValues.
 
 	All MetaValues within a MetaItem have the same key.
 
@@ -1133,7 +1133,7 @@ def stanFactory(tag, **kwargs):
 			attrs = kwargs
 
 		if isinstance(tag, type):
-			# this presumably is a stanxml.Element.  Instanciate first
+			# this presumably is a stanxml.Element.  Instantiate first
 			el = tag()
 		elif hasattr(tag, "clone"):
 			# this ought to be something t.w.template.Tag-like
