@@ -10,12 +10,12 @@ of a given object type.  Defined assertions are
 		and has a single value
 
 Validators are usually built using model descriptions.  These are enumerations
-of meta keys, separated by commata, with an optional code in parenteses.
+of meta keys, separated by commas, with an optional code in parenteses.
 Whitespace is ignored.  Codes allowed in parens are:
 
 	- empty (default): plain existence
-	- !: atomic existance on self
-	- 1: atomic existance
+	- !: atomic existence on self
+	- 1: atomic existence
 
 An example for a valid model description: 
 "publisher.name,creator.email(), identifier (!), dateUpdated(1)"
