@@ -17,7 +17,6 @@ import re
 import os
 import subprocess
 import time
-import urllib.request, urllib.parse, urllib.error
 import urllib.parse
 from email import charset
 from email import utils as emailutils
@@ -142,9 +141,9 @@ def getCurrentServerURL():
 	if config.get("web", "adaptProtocol"):
 		frame = inspect.currentframe().f_back.f_back
 		while frame:
-			if "self" in frame.f_locals:
-				if hasattr(frame.f_locals["self"], "isSecure"):
-					if frame.f_locals["self"].isSecure():
+			if "request" in frame.f_locals:
+				if hasattr(frame.f_locals["request"], "isSecure"):
+					if frame.f_locals["request"].isSecure():
 						return getHTTPSBase()
 					else:
 						return getHTTPBase()
@@ -227,8 +226,6 @@ def getVersion():
 def formatMail(mailText):
 	"""returns a mail with headers and content properly formatted as
 	a bytestring and MIME.
-
-	mailText must be a unicode instance or pure ASCII
 	"""
 	rawHeaders, rawBody = mailText.split("\n\n", 1)
 	cs = charset.Charset("utf-8")
