@@ -551,7 +551,7 @@ class ParseContext(object):
 		self.idmap[elId] = value
 	
 	def getById(self, id, forceType=None):
-		"""returns the object last registred for id.
+		"""returns the object last registered for id.
 
 		You probably want to use resolveId; getById does no namePath or
 		resource descriptor resolution.
