@@ -251,6 +251,11 @@ class GAVOConnection(psycopg2.extensions.connection):
 	arguments to the connection; it is used when recovering from
 	a database restart.
 	"""
+	# extensionFunctions is filled by _initPsycopg on the class level
+	# (and contains names of postgres extension functions that might
+	# modify our behaviour
+	extensionFunctions = None
+
 	def getParameter(self, key, cursor=None):
 		"""returns the value of the postgres parameter key.
 
@@ -319,7 +324,7 @@ class GAVOConnection(psycopg2.extensions.connection):
 		"""iterates over dictionary rows for query.
 	
 		This is a thin wrapper around query(yieldDicts=True) provided
-		for convenience and backwards compatiblity.
+		for convenience and backwards compatibility.
 		"""
 		return self.query(query, args, timeout, True, caseFixer)
 
@@ -595,7 +600,7 @@ class PostgresQueryMixin(object):
 		if len(res)==1:
 			return res[0][0]
 		else:
-			raise ValueError("Non-existing or ambiguos foreign key")
+			raise ValueError("Non-existing or ambiguous foreign key")
 
 	def foreignKeyExists(self, srcTableName, destTableName, srcColNames, 
 			destColNames, schema=None):
@@ -622,7 +627,7 @@ class PostgresQueryMixin(object):
 		return res[0][0]
 
 	def getColumnsFromDB(self, tableName):
-		"""returns a sequence of (name, type) pairs of the columsn this
+		"""returns a sequence of (name, type) pairs of the columns this
 		table has in the database.
 
 		If the table is not on disk, this will raise a NotFoundError.
@@ -909,7 +914,7 @@ class QuerierMixin(PostgresQueryMixin, StandardQueryMixin):
 		if self.connection is None:
 			raise utils.ReportableError(
 				"SimpleQuerier connection is None.",
-				hint="This ususally is because an AdhocQuerier's query method"
+				hint="This usually is because an AdhocQuerier's query method"
 				" was used outside of a with block.")
 		
 		try:
@@ -1099,13 +1104,35 @@ SELECT (
 ' LANGUAGE SQL IMMUTABLE;
 """
 
+
+def onDBInit(func):
+	"""runs func(conn) with an administrator connection during database
+	initialisation (or immediately if the database is already initialised).
+
+	This is done in order to let modules do database initialisation while
+	they are imported without colliding with the module lock problems of
+	the connection pools.
+
+	If func fails, it will stop the DaCHS startup, so be extra careful
+	with what you do in there.
+	"""
+	if _PSYCOPG_INITED:
+		with getWritableAdminConn() as conn:
+			func(conn)
+
+	else:
+		onDBInit.initFuncs.append(func)
+
+onDBInit.initFuncs = []
+
+
 def _initPsycopg():
 	"""does any DaCHS-specific database setup necessary.
 
 	This will always open an admin connection.
 	"""
-# collect all DB setup in this function.  XXX TODO: in particular, the
-# Box mess from coords (if we still want it)
+# collect all DB setup in this function or use onDBInit.  XXX TODO: 
+# in particular, the Box mess from coords (if we still want it)
 	global _PSYCOPG_INITED
 
 	conn = psycopg2.connect(connection_factory=GAVOConnection,
@@ -1133,6 +1160,15 @@ def _initPsycopg():
 				leftra double precision, leftdec double precision,
       	rightra real, rightdec real,
       	radius double precision) RETURNS boolean AS '"""+JOIN_FUNCTION_BODY)
+
+		GAVOConnection.extensionFunctions = frozenset(r[0] for r in 
+			conn.query(
+     		"SELECT proname FROM pg_proc WHERE"
+     		"  proname in ('epoch_prop', 'q3c_ang2ipix',"
+     		"    'smoc_union', 'healpix_nest')"))
+
+		for func in onDBInit.initFuncs:
+			func(conn)
 	finally:
 		conn.commit()
 		conn.close()
