@@ -471,7 +471,8 @@ class RestrictionMixin(common.StructCallbacks):
 def makeStruct(structClass, **kwargs):
 	"""creates a parentless instance of structClass with ``**kwargs``.
 
-	You can pass in a ``parent_`` kwarg to force a parent.
+	You can pass in a ``parent_`` kwarg to force a parent, and a ``ctx_``
+	if you need a parse context.
 
 	This is the preferred way to create struct instances in DaCHS, as it
 	will cause the sequence of completers and validators run.  Use it like
@@ -479,7 +480,6 @@ def makeStruct(structClass, **kwargs):
 
 		MS(rscdef.Column, name="ra", type="double precision)
 	"""
-	parent = None
-	if "parent_" in kwargs:
-		parent = kwargs.pop("parent_")
-	return structClass(parent, **kwargs).finishElement()
+	ctx = kwargs.pop("ctx_", None)
+	parent = kwargs.pop("parent_", None)
+	return structClass(parent, **kwargs).finishElement(ctx)
