@@ -110,7 +110,7 @@ PLAIN_UNITS = units = {
 
 EXCEPTIONAL_CONVERSIONS = {
 	# tuple-form of units: conversions that are still linear but
-	# somehow ideosyncratic.
+	# somehow idiosyncratic.
 
 	# wave number to energy
 	((('m', -1.0),), (('J', 1),)): PLANCK_H*LIGHT_C,
@@ -401,7 +401,7 @@ class Term(_Node):
 	def getFactorWithUnit(self, unit):
 		"""returns a factor within self with unit if it exists.
 
-		Actually, it will return that factor and the exponentation factor,
+		Actually, it will return that factor and the exponentiation factor,
 		which is -1 if that factor is in the denominator, 1 otherwise.
 		This returns None, None if no such factor exists.
 		"""
@@ -714,6 +714,12 @@ def getSpecExpr(fromUnit, toUnit):
 		toFactor)
 
 
+def getSpecConverter(fromUnit, toUnit):
+	"""Returns a function converting spectral values in fromUnit to toUnit.
+	"""
+	return eval("lambda x: "+getSpecExpr(fromUnit, toUnit).format("x"))
+
+
 if __name__=="__main__":
 	getUnitGrammar.enableDebuggingOutput()
 	g = getUnitGrammar()
