@@ -77,7 +77,7 @@ class SynthesizedRoles(base.Structure):
 
 	def completeElement(self, ctx):
 		ctx.addExitFunc(self.synthesizeAnnotations)
-		self._completeElementNext(SynthesizedRoles, ctx)
+		super().completeElement(ctx)
 
 
 class DataModelRoles(base.Structure):
@@ -118,7 +118,7 @@ class DataModelRoles(base.Structure):
 		self._buildAnnotation = _buildAnnotation
 
 		ctx.addExitFunc(lambda rd, ctx: self._buildAnnotation())
-		self._completeElementNext(DataModelRoles, ctx)
+		super().completeElement(ctx)
 
 	def parse(self):
 		"""returns a parsed version of the embedded annotation.
