@@ -8,6 +8,7 @@ from zope.interface import Interface
 from twisted.internet import defer
 from twisted.python.components import registerAdapter
 from twisted.web import iweb
+from twisted.web import resource
 from twisted.web import server
 from twisted.web import template
 from twisted.web.template import tags as T
@@ -160,7 +161,7 @@ class FieldFragment(nevowc.CommonRenderers, template.Element):
             # there was an error.
             formData = util.CaseSemisensitiveDict(
                 [(k.decode("utf-8", "ignore"),v) 
-                for k,v in list(request.args.items())])
+                for k,v in request.args.items()])
         else:
             error = None
 
@@ -193,6 +194,7 @@ class FieldFragment(nevowc.CommonRenderers, template.Element):
             render = widget.render
 
         # Fill the slots
+        tag.slotData = {}
         tag.fillSlots(id=util.render_cssid(field.key),
             fieldId=[util.render_cssid(field.key), '-field'],
             cls=' '.join(classes),
@@ -202,7 +204,7 @@ class FieldFragment(nevowc.CommonRenderers, template.Element):
             message=message,
             description=T.div(class_='description')[field.description or ''])
 
-        return tag
+        return tag(render="mapping")
 
 
 registerAdapter(FieldFragment, Field, iweb.IRenderable)
@@ -324,7 +326,6 @@ registerAdapter(GroupFragment, Group, iweb.IRenderable)
 @implementer( iformal.IForm )
 class Form(AddHelperMixin, object):
 
-
     callback = None
     actions = None
 
@@ -361,7 +362,7 @@ class Form(AddHelperMixin, object):
 
         # Get the request args and decode the arg names
         args = util.CaseSemisensitiveDict(
-            [(k.decode(charset),v) for k,v in list(request.args.items())])
+            [(k.decode(charset),v) for k,v in request.args.items()])
 
         # Find the callback to use, defaulting to the form default
         callback, validate = self.callback, True
@@ -373,7 +374,7 @@ class Form(AddHelperMixin, object):
                     # Remember the callback and whether to validate
                     callback, validate = action.callback, action.validate
                     break
-
+        
         # IE does not send a button name in the POST args for forms containing
         # a single field when the user presses <enter> to submit the form. If
         # we only have one possible action then we can safely assume that's the
@@ -573,7 +574,15 @@ class ResourceWithForm(nevowc.TemplatedPage):
     
     def render(self, request, customCallback=None):
         def gotResult(result):
-            return super(ResourceWithForm, self).render_POST(request)
+            if isinstance(result, resource.Resource):
+                res = result.render(request)
+                if res==server.NOT_DONE_YET:
+                    return res
+                else:
+                    request.finish()
+                    return server.NOT_DONE_YET
+            else:
+                return super(ResourceWithForm, self).render_POST(request)
 
         formName = request.args.pop(FORMS_KEY, [b""])[0].decode("utf-8")
 
@@ -592,11 +601,11 @@ class ResourceWithForm(nevowc.TemplatedPage):
 #        import sys; failure.printTraceback(file=sys.stdout)
         request.setResponseCode(500)
         request.setHeader("content-type", "text/plain")
-        request.write("Unhandled exception while handling the form:\n\n")
-        request.write(failure.getErrorMessage()+"\n\n")
-        request.write("You will probably want to complain to the operators.\n")
-        request.write("If you *are* the operator, override"
-            " the page.crash(failure, request) method.")
+        request.write(b"Unhandled exception while handling the form:\n\n")
+        request.write((failure.getErrorMessage()+"\n\n").encode("utf-8"))
+        request.write(b"You will probably want to complain to the operators.\n")
+        request.write(b"If you *are* the operator, override"
+            b" the page.crash(failure, request) method.")
         request.finish()
         return server.NOT_DONE_YET
 
@@ -649,7 +658,7 @@ class FormRenderer(nevowc.CommonRenderers):
 
     def render(self, request):
         data = self.original.data
-        tag = T.transparent[self.loader.load()]
+        tag = T.transparent[self.loader.load()](render="mapping")
         tag.fillSlots(
             formName=self.original.name,
             formAction=request.path,
