@@ -13,9 +13,11 @@ See porting guide in the README.
 
 import io
 import itertools 
+import sys
 
 from xml.sax import make_parser, handler
 
+from twisted.internet import defer
 from twisted.python.filepath import FilePath
 from twisted.web import resource
 from twisted.web import server
@@ -247,7 +249,7 @@ def addNevowAttributes(tag, **kwargs):
 
 
 class CommonRenderers(object):
-    """A container for some basic renderers we want on all actice
+    """A container for some basic renderers we want on all active
     elements.
 
     This is basically what nevow had.
@@ -257,7 +259,7 @@ class CommonRenderers(object):
         toProcess = tag.slotData
 
         patterns = locatePatterns(tag, 
-            ["item", "empty", "separator", "header"], 
+            ["item", "empty", "separator", "header", "footer"], 
             ["sequence"])
         if not patterns["item"]:
             patterns["item"] = [template.tags.transparent]
@@ -279,6 +281,9 @@ class CommonRenderers(object):
             newTag(nextTag.clone(True, item))
         
         if newTag.children or not patterns["empty"]:
+            if patterns["footer"]:
+                newTag[patterns["footer"]]
+
             return newTag
         else:
             return patterns["empty"]
@@ -437,9 +442,18 @@ class TemplatedPage(resource.Resource, CommonRenderers):
 
     def handleError(self, failure, request):
         failure.printTraceback()
-        request.write("Uncaught error:\n<![CDATA[\n%s\n]]>\n"
-            %failure.getErrorMessage())
-        request.finish()
+        request.write("Uncaught error:\n<![CDATA[\n{}\n]]>\n"
+            .format(failure.getErrorMessage())
+            .encode("utf-8"))
+        try:
+            request.finish()
+        except defer.AlreadyCalledError:
+            # I can't say what state I'm in at this state.  If the request
+            # was already finished nobody saw the message, so at least
+            # gargle it out on stderr and hope for the best
+            sys.stderr.write("Error on request that was already finished:\n")
+            sys.stderr.write(failure.getErrorMessage())
+            pass
 
     def renderDocument(self, request):
         """returns a deferred firing when the document is written.
