@@ -1,7 +1,7 @@
 """
 Code to add some basic nevow functionality back to twisted.
 
-This needs ot be imported as early as possible after importing twisted.web
+This needs to be imported as early as possible after importing twisted.web
 for the first time.
 
 The features were adding include:
@@ -18,7 +18,6 @@ The features were adding include:
 #c This program is free software, covered by the GNU GPL.  See the
 #c COPYING file in the source distribution.
 
-
 from twisted.web import _flatten
 from twisted.web import _stan 
 
@@ -338,14 +337,15 @@ def _loadNevowData(request, tag, renderFactory):
     """
     if "nevow:data" not in tag.attributes:
         return tag
-   
-    dataFct = renderFactory.lookupDataMethod(
-        tag.attributes["nevow:data"])
+  
+    dataSpec = tag.attributes["nevow:data"]
+    if callable(dataSpec):
+        dataFct = dataSpec
+    else:
+        dataFct = renderFactory.lookupDataMethod(dataSpec)
 
     newData = dataFct(request, tag)
 
     res = tag.clone(True, newData)
     del res.attributes["nevow:data"]
     return res
-
-
