@@ -3,7 +3,7 @@ Common code for generation of various data formats.
 
 The main function here is formatData.  It receives a string format id, a data
 instance and a destination file (binary mode).  It dispatches this to
-formatters previously registred using registerDataWriter.
+formatters previously registered using registerDataWriter.
 
 The data writers must take a data instance and a file instance; their
 effect must be that a serialized representation of data, or, if the format
@@ -11,7 +11,7 @@ does not support this, the data's primary table is written to the file
 instance.
 """
 
-#c Copyright 2008-2021, the GAVO project <gavo@ari.uni-heidelberg.de>
+#c Copyright 2008-2022, the GAVO project <gavo@ari.uni-heidelberg.de>
 #c
 #c This program is free software, covered by the GNU GPL.  See the
 #c COPYING file in the source distribution.
@@ -43,7 +43,7 @@ class CannotSerializeIn(base.Error):
 		self.format = format
 		base.Error.__init__(self, format,
 			hint="Either you gave an invalid format id or a known format"
-			" did not get registred for some reason.  Format codes"
+			" did not get registered for some reason.  Format codes"
 			" known at this point: %s.  You can also try common MIME types"%(
 				", ".join(FORMATS_REGISTRY.writerRegistry)))
 		self.args = [format]
@@ -110,7 +110,7 @@ class FORMATS_REGISTRY(object):
 		that can be used to select the format in DALI FORMAT or similar.
 
 		Where keys, mainMime, and aliases clash, previous entries are
-		silently overwritten.  For extensions, the first registred format
+		silently overwritten.  For extensions, the first registered format
 		wins.
 		"""
 		cls.writerRegistry[key] = writer
@@ -162,7 +162,7 @@ class FORMATS_REGISTRY(object):
 	def getWriterFor(cls, formatName):
 		"""returns a writer for formatName.
 
-		writers are what's registred via registerDataWriter; formatName is
+		writers are what's registered via registerDataWriter; formatName is
 		a MIME type or a format alias.  This raises CannotSerializeIn
 		if no writer is available.
 		"""
