@@ -265,7 +265,7 @@ def writeFITSTableFile(hdulist):
 		hdulist[0].header.set("EXTEND", True, "More exts following")
 
 	with utils.silence():
-		hdulist.writeto(pathname, clobber=1)
+		hdulist.writeto(pathname, overwrite=True)
 	os.close(handle)
 	return pathname
 
