@@ -6,7 +6,7 @@ ASCII as well, though that may be a bit tricky given that we do not
 really store sane formatting hints for most columns.
 """
 
-#c Copyright 2008-2021, the GAVO project <gavo@ari.uni-heidelberg.de>
+#c Copyright 2008-2022, the GAVO project <gavo@ari.uni-heidelberg.de>
 #c
 #c This program is free software, covered by the GNU GPL.  See the
 #c COPYING file in the source distribution.
@@ -81,6 +81,25 @@ def _dmsMapperFactory(colDesc):
 registerDisplayMF(_dmsMapperFactory)
 
 
+def _specUnitMapperFactory(colDesc):
+	"""returns a factory that converts between spectral units based
+	on a spectralUnit displayHint.
+
+	In contract to unitMapperFactory, this supports non-linear conversions.
+	"""
+	spUnit = colDesc["displayHint"].get("spectralUnit")
+	if spUnit and spUnit!=colDesc["unit"]:
+		fmtStr = "'%%.%df'"%int(colDesc["displayHint"].get("sf", 2))
+		expr = base.getSpecExpr(colDesc["unit"], spUnit).format("val")
+		code = ("def coder(val):\n  if val is None:\n    return 'N/A'\n"
+			f"  else:\n    return {fmtStr}%({expr})")
+		colDesc["unit"] = spUnit
+		return utils.compileFunction(code, "coder")
+
+
+registerDisplayMF(_specUnitMapperFactory)
+
+
 def _unitMapperFactory(colDesc):
 	"""returns a factory that converts between units for fields that have
 	a displayUnit displayHint.
@@ -237,7 +256,7 @@ def _makeString(val):
 	if val is None:
 		return "N/A"
 	elif isinstance(val, str):
-		# a cheaty way of making sure we get hex excapes for non-printable stuff
+		# a cheaty way of making sure we get hex escapes for non-printable stuff
 		return repr(val)[1:-1]
 	elif isinstance(val, bytes):
 		return repr(val)[2:-1]
