@@ -835,7 +835,7 @@ def makeTable(ctx, table, isMeta=False):
 		_addLegacyPhotCal(ctx, table.tableDef, sm)
 
 		result(
-				name=table.tableDef.id,
+				name=base.getMetaText(table, "name", table.tableDef.id),
 				utype=base.getMetaText(table, "utype", macroPackage=table.tableDef,
 				propagate=False))[
 			# _iterGroups must run before _iterFields and _iterParams since it
