@@ -69,4 +69,4 @@ class CDFHeaderGrammar(Grammar):
 	def onElementComplete(self):
 		if self.mapKeys is None:
 			self.mapKeys = base.makeStruct(MapKeys)
-		self._onElementCompleteNext(CDFHeaderGrammar)
+		super().onElementComplete()
