@@ -47,7 +47,7 @@ class REAttribute(base.UnicodeAttribute):
 
 
 class FilteredInputFile(object):
-	"""a pseudo-file that allows piping data thorugh a shell command.
+	"""a pseudo-file that allows piping data through a shell command.
 
 	It supports read, readline, and close.  Close closes the original
 	file, too.
@@ -456,7 +456,7 @@ class FileRowIterator(RowIterator):
 	
 	def _openFile(self):
 		preFilter = None
-		# we'll use at the end to generate a sourceToken for disply purposes
+		# we'll use at the end to generate a sourceToken for display purposes
 		parsingFrom = self.sourceToken
 		if hasattr(parsingFrom, "name"):
 			# it' probably an open file
@@ -688,7 +688,7 @@ class Grammar(base.Structure, GrammarMacroMixin):
 	# isDispatching is used by various special grammars to signify the
 	# grammar returns rowdicts for multiple makers.  See those.
 	# Here, we just fix it to false so clients can rely on the attribute's
-	# existance.
+	# existence.
 	isDispatching = False
 
 	rowIterator = RowIterator
