@@ -258,7 +258,8 @@ class DirectGrammar(base.Structure, base.RestrictionMixin):
 			preFilter=self.preFilter,
 			autoNull=self.autoNull,
 			ignoreBadRecords=self.ignoreBadRecords,
-			customFlags=self.customFlags)
+			customFlags=self.customFlags,
+			recordSize=self.recordSize)
 
 	def parse(self, sourceToken, targetData=None):
 		booster = self.getBooster()
@@ -395,7 +396,7 @@ class _CodeGenerator(object):
 		"""returns code that parses item (a Column instance) at column index
 		index.
 
-		You're free to igore index.
+		You're free to ignore index.
 		"""
 		return []
 
