@@ -29,7 +29,7 @@ class FITSTableIterator(common.RowIterator):
 			if self.grammar.nanIsNULL:
 				row = [v if v==v else None for v in row]
 
-			res = dict(list(zip(names, row)))
+			res = dict(zip(names, row))
 			yield res
 
 
