@@ -114,7 +114,7 @@ class ODBCGrammar(Grammar):
 	rowIterator = ODBCIterator
 
 	def validate(self):
-		self._validateNext(ODBCGrammar)
+		super().validate()
 		if self.query and self.makeQuery:
 			raise base.StructureError("Cannot give both query and makeQuery"
 				" in an odbcGrammar.")
@@ -126,4 +126,4 @@ class ODBCGrammar(Grammar):
 		if ctx.restricted and self.makeQuery:
 			raise base.RestrictedElement("makeQuery")
 
-		self._completeElementNext(ODBCGrammar, ctx)
+		super().completeElement(ctx)
