@@ -58,5 +58,5 @@ class RowsetGrammar(common.Grammar):
 		description="the table defining the columns in the tuples.", copyable=True)
 
 	def onElementComplete(self):
-		self._onElementCompleteNext(RowsetGrammar)
+		super().onElementComplete()
 		self.names = [c.name for c in self.fieldsFrom]
