@@ -188,6 +188,7 @@ WFPDB_TEMPLATE = MINIMAL_IMAGE_TEMPLATE+[
 		("TIMEFLAG", "Quality flag of the recorded observation time"),
 		("RA-ORIG",  "RA of plate center as given in source"),
 		("DEC-ORIG", "Dec of plate center as given in source"),
+		("EQ-ORIG",  "Equinox of RA-ORIG and DEC-ORIG"),
 		("COORFLAG", "Quality flag of the recorded coordinates"),
 		("OBJECT",   "Observed object or field"),
 		("OBJTYPE",  "Object type as in WFPDB"),
@@ -205,17 +206,16 @@ WFPDB_TEMPLATE = MINIMAL_IMAGE_TEMPLATE+[
 			"OBJTYP%d",  "Object type of %s OBJECT"
 		)+_makeHeaderSequence(
 			"EXPTIM%d",  " [s] Exposure time %s exposure")+[
-
-		pyfits.Card(value="-------------------- Observatory and instrument"),
 		("OBSERVAT", "Observatory name"),
 		("SITENAME", "Observatory site name."),
 		("SITELONG", " [deg] East longitude of observatory"),
 		("SITELAT", " [deg] Latitude of observatory"),
 		("SITEELEV", " [m] Elevation of the observatory"),
-		("TELESCOP", "Telescope name"),
-		("TELAPER", " [m] Clear aperture of the telescope"),
-		("TELFOC", " [m] Focal length of the telescope"),
-		("TELSCALE", " [arcsec/mm] Plate scale"),
+		("OTA-NAME", "Telescope name"),
+		("OTA-DIAM", " [m] Clear aperture of the telescope"),
+		("OTA-APER", " [m] Clear aperture of the telescope"),
+		("FOCLEN", " [m] Focal length of the telescope"),
+		("PLTSCALE", " [arcsec/mm] Plate scale of the OTA"),
 		("INSTRUME", "Instrument name"),
 		("DETNAM", "Detector name"),
 		("METHOD", "Observation method as in WFPDB"),
@@ -229,22 +229,23 @@ WFPDB_TEMPLATE = MINIMAL_IMAGE_TEMPLATE+[
 		("CALMNESS", "Calmness (seeing conditions), scale 1-5"),
 		("SHARPNES", "Sharpness, scale 1-5"),
 		("TRANSPAR", "Transparency, scale 1-5"),
+		("SEEING", "Quantitative measure on the seeing"),
 		("SKYCOND", "Notes on sky conditions (logs)"),
-		("OBSERVER", ""),
+		("OBSERVER", "Observer name"),
 		("OBSNOTES", "Observer notes (logs)"),
+		("NOTES", "Miscellaneous notes found in the observation logbook"),
 
 		pyfits.Card(value="-------------------- Photographic plate"),
 		("PLATENUM", "Plate number in logs"),
 		("WFPDB-ID", "Plate identifier in WFPDB"),
 		("SERIES", "Series or survey of plate"),
-		("PLATEFMT", "Informal designation of plate format"),
 		("PLATESZ1", " [cm] Plate size along axis1"),
 		("PLATESZ2", " [cm] Plate size along axis2"),
-		("FOV1", "Field of view along axis 1"),
-		("FOV2", "Field of view along axis 2"),
 		("EMULSION", "Type of the photographic emulsion"),
+		("DEVELOP", "Plate development (developer, time)"),
 		("PQUALITY", "Quality of the plate"),
 		("PLATNOTE", "Notes about the plate"),
+		("PRE-PROC", "Processing applied to the plate before scanning"),
 
 		pyfits.Card(value="-------------------- Derived observation data"),
 		("DATE-OBS", "UT date and time of obs. start"),
@@ -296,19 +297,23 @@ WFPDB_TEMPLATE = MINIMAL_IMAGE_TEMPLATE+[
 		("DATESCAN", "UT scan date and time"),
 		("SCANAUTH", "Author of the scan"),
 		("SCANNOTE", "Notes about the scan"),
-		("DATAMIN",  "Min pixel value in image"),
-		("DATAMAX",  "Max pixel value in image"),
 
 		pyfits.Card(value="-------------------- Data files"),
 		("FILENAME", "Filename of this file"),
+		("PID", "Persistent identifier for the plate"),
+		]+_makeHeaderSequence(
+			"FN-SCN%d", "Filename of %s scan of this plate")+[
 		("FN-WEDGE", "Filename of the wedge scan"),
 		("FN-PRE", "Filename of the preview image"),
 		("FN-COVER", "Filename of the envelope image"),
 		("FN-LOGB", "Filename of the logbook image"),
 		("ORIGIN", "Origin of this file"),
 		("DATE", "File last changed"),
+		("SVC-URI", "Where to get these files"),
 		
 		] + WCS_TEMPLATE + [
+		pyfits.Card(value="-------------------- History/Legal"),
+		("LICENCE", "URI for conditions of use"),
 
 		pyfits.Card(value="-------------------- Other header cards"),]
 
@@ -339,20 +344,20 @@ def getTemplateForName(templateName):
 		if name==templateName:
 			return template
 	raise base.NotFoundError(templateName, "FITS template",
-		"registred templates", hint="If you used a custom template,"
+		"registered templates", hint="If you used a custom template,"
 		" have you called fitstricks.registerTemplate(name, template)"
 		" for it?")
 
 
 def getNameForTemplate(template):
-	"""returns the name under which the FITS template has been registred.
+	"""returns the name under which the FITS template has been registered.
 	"""
 	for name, namedTemplate in _TEMPLATE_NAMES:
 		if template is namedTemplate:
 			return name
 	raise base.NotFoundError("template "+str(id(template)), 
 		"FITS template",
-		"registred templates", hint="If you used a custom template,"
+		"registered templates", hint="If you used a custom template,"
 		" have you called fitstricks.registerTemplate(name, template)"
 		" for it?")
 
