@@ -88,7 +88,7 @@ else:
 				base.getConfig("configDir"), "defaultmeta.txt"), "a", 
 				encoding="utf-8") as f:
 			f.write("!organization.description: Mein wüster Club\n")
-			f.write("!contact.email: invalid@whereever.else\n")
+			f.write("!contact.email: invalid@wherever.else\n")
 
 		with open(os.path.join(
 				base.getConfig("configDir"), "vanitynames.txt"), "w") as f:
@@ -117,6 +117,8 @@ else:
 				from gavo.base import sqlsupport
 				# update the type bindings
 				importlib.reload(sqlsupport)
+				# update the UDFs
+				importlib.reload(ufunctions)
 
 				from gavo.registry import publication
 				from gavo import rsc
@@ -155,6 +157,7 @@ osinter.sendMail = lambda *args, **kwargs: None
 from gavo import utils
 from gavo.base import config
 from gavo.base import sqlsupport
+from gavo.adql import ufunctions
 
 class FakeSimbad(object):
 	"""we monkeypatch simbadinterface such that we don't query simbad during
@@ -707,6 +710,19 @@ def getTestData(dataId):
 	return getTestRD().getDataById(dataId)
 
 
+def hasUDF(udfName):
+	"""returns true if this system has an ADQL user defined function named 
+	udfName.
+
+	This is intended to be used as in::
+
+		@unittest.skipUnless(testhelpers.hasUDF("GAVO_FOO"), "...")
+	
+	Caution: UDF names are upper case here.
+	"""
+	return udfName in ufunctions.UFUNC_REGISTRY
+
+
 def captureOutput(callable, args=(), kwargs={}):
 	"""runs ``callable(*args, **kwargs)`` and captures the output.
 
