@@ -95,6 +95,11 @@ def _makeColumnFromFieldInfo(ctx, colName, fi):
 	res.ucd = fi.ucd
 	res.unit = fi.unit
 	res.type = fi.type
+	if res.type is None:
+		# that's a literal NULL; it doesn't matter much what we use
+		# here, but the least troublesome NULLs in VOTable are for
+		# floats, so let's use them
+		res.type = 'real'
 
 	# XXX TODO: do something with stc's "broken" attribute
 	res.stc = fi.stc
@@ -106,6 +111,10 @@ def _makeColumnFromFieldInfo(ctx, colName, fi):
 	if fi.tainted:
 		res.description = (res.description+" -- *TAINTED*: the value"
 			" was operated on in a way that unit and ucd may be severely wrong")
+	if (fi.properties.get("src-expression", res.name)
+			!=res.name):
+		res.description += " [ADQL: {}]".format(
+			fi.properties["src-expression"])
 
 	# The xtype may be set by the node classes; this is used downstream
 	# to transform to STC-S strings.
@@ -132,6 +141,12 @@ def _makeColumnFromFieldInfo(ctx, colName, fi):
 			res.feedObject("values", base.makeStruct(rscdef.Values, 
 				nullLiteral=nullLiteral))
 
+	# unconditionally do away with tableheads inherited from columns
+	# that have annotation indicating they're not plain column references
+	if "src-expression" in fi.properties:
+		res.tablehead = utils.makeEllipsis(
+			fi.properties["src-expression"], 30, "…")
+
 	res.verbLevel = 1
 	res.finishElement()
 	return res
@@ -151,9 +166,10 @@ def _getTableDescForOutput(parsedTree):
 		for t in parsedTree.fromClause.getAllTables()
 		if hasattr(t, "qName")]
 
+	mth = base.caches.getMTH(None)
 	if len(fromNames)==1:
 		try:
-			srcTable = base.caches.getMTH(None).getTableDefForTable(fromNames[0])
+			srcTable = mth.getTableDefForTable(fromNames[0])
 			# swallow groups for now -- we don't really use them for db tables
 			# but if there are some, they'll be trouble when columns are missing.
 			resTable = srcTable.change(columns=columns, groups=[], primary=())
@@ -165,7 +181,22 @@ def _getTableDescForOutput(parsedTree):
 			# fall through to normal table generation
 			pass
 
-	resTable = base.makeStruct(rscdef.TableDef, columns=columns,
+	# collect the params from all input tables; if there are conflicting
+	# names, we pick one at random (which is about as wrong as anything else;
+	# there's just no way to know what the collision means).
+	params = []
+	for tableName in fromNames:
+		try:
+			params.extend(p.copy(parent=None) 
+				for p in mth.getTableDefForTable(tableName).params)
+		except Exception:
+			# don't fail just because a funny thing is in fromNames
+			pass
+
+	resTable = base.makeStruct(
+		rscdef.TableDef, 
+		columns=columns,
+		params=params,
 		id=parsedTree.suggestAName())
 
 	return resTable
@@ -506,15 +537,9 @@ class ADQLCore(svcs.Core, base.RestrictionMixin):
 
 
 
-################ region makers (maybe put these in a separate module later)
-# The region maker should in general either call the parser with an ADQL
-# fragment (see _makeSimbadRegion) or return a complete FieldInfoedNode
-# including any info required with a node type of psqlLiteral (for
-# postgres, let's see what happens if we want to support other DBs).
-# 
-# There are no guarantees that we won't parse out more symbols later,
-# and hardcoded trees would break then.
-
+################ region makers
+# REGION was supposed to be a general extension mechanism but will now
+# probably wither away.  Let's keep things here while it does that.
 import re
 
 def _getRegionId(regionSpec, pat=re.compile("[A-Za-z_]+")):
