@@ -41,7 +41,7 @@ MS = base.makeStruct
 
 class DatalinkDescriptorMixin:
 	"""some generally useful methods that various code
-	expectes datalink descriptors to have.
+	expects datalink descriptors to have.
 	"""
 	data = None
 	forSemantics = DEFAULT_SEMANTICS
@@ -50,14 +50,16 @@ class DatalinkDescriptorMixin:
 		"""returns a LinkDef for this descriptor for url.
 
 		kwargs are passed on to LinkDef and include, in particular,
-		semantics, contentType, contentLength, and description.
+		semantics, contentType, contentLength, description, and
+		localSemantics.
 		"""
 		if not "semantics" in kwargs:
 			kwargs["semantics"] = self.forSemantics
 		return LinkDef(self.pubDID, url, **kwargs)
 
 	def makeLinkFromFile(self, localPath, description, semantics=None,
-			service=None, contentType=None, suppressMissing=False):
+			service=None, contentType=None, suppressMissing=False,
+			localSemantics=None):
 		"""returns a LinkDef for a local file.
 
 		Arguments are as for LinkDef.fromFile, except you don't have
@@ -77,7 +79,7 @@ class DatalinkDescriptorMixin:
 
 		return LinkDef.fromFile(localPath, description, semantics,
 			service=service, contentType=contentType, 
-			suppressMissing=suppressMissing)
+			suppressMissing=suppressMissing, localSemantics=localSemantics)
 
 	@contextlib.contextmanager
 	def currentSemantics(self, sem):
@@ -272,7 +274,7 @@ class DescriptorGenerator(rscdef.ProcApp):
 
 		- pubDID -- the pubDID to be resolved
 		- args -- all the arguments that came in from the web
-			(these should not ususally be necessary for making the descriptor
+			(these should not usually be necessary for making the descriptor
 			and are completely unparsed at this point)
 		- FITSProductDescriptor -- the base class of FITS product descriptors
 		- DLFITSProductDescriptor -- the same, just for when the product table
@@ -307,35 +309,41 @@ class DescriptorGenerator(rscdef.ProcApp):
 	}
 
 
-class LinkDef(object):
+class LinkDef:
 	"""A definition of a datalink related document.
 
 	These are constructed at least with:
 
 	- the pubDID (as a string)
-	 - the access URL (as a string)
+	- the access URL (as a string)
 
 	In addition, we accept the remaining column names from 
-	`//datalink#dlresponse`_ as keyword arguments.
+	`//datalink#dlresponse`_ as keyword arguments, except we use
+	camel case here, i.e., 
+	``description``, ``semantics``, ``contentType``, ``contentLength``,
+	``localSemantics``.
 
-	In particular, do set semantics with a term from 
-	http://www.ivoa.net/rdf/datalink/core.  This includes ``#this``, ``#preview``,
-	``#calibration``, ``#progenitor``, ``#derivation``
+	You usually do not want to construct LinkDefs directly.  Use
+	the makeLink or makeLinkFromFile methods on descriptors instead.
+	Also, define semantics via the attribute on `element metaMaker`_
+	whenever you can; that will improve error messages.
 	"""
-	def __init__(self, pubDID, accessURL, 
+	def __init__(self, pubDID, accessURL,
 			serviceType=None, 
 			errorMessage=None,
 			description=None, 
 			semantics=DEFAULT_SEMANTICS,
 			contentType=None, 
-			contentLength=None):
+			contentLength=None,
+			localSemantics=None):
 		ID = pubDID #noflake: used in locals()
 		del pubDID
 		self.dlRow = locals()
 
 	@classmethod
 	def fromFile(cls, localPath, description, semantics, 
-			service, contentType=None, suppressMissing=False):
+			service, contentType=None, localSemantics=None, 
+			suppressMissing=False):
 		"""constructs a LinkDef based on a local file.
 		
 		You must give localPath (which may be resdir-relative), description and
@@ -373,7 +381,8 @@ class LinkDef(object):
 		except ValueError:
 			return LinkDef(pubDID, errorMessage="FatalFault: Linked item"
 				" not accessible through the given service", 
-				semantics=semantics, description=description)
+				semantics=semantics, description=description, 
+				localSemantics=localSemantics)
 
 		ext = os.path.splitext(localPath)[-1]
 		contentType = (contentType 
@@ -383,7 +392,8 @@ class LinkDef(object):
 			service.getURL("static")+"/"+svcPath,
 			description=description, semantics=semantics,
 			contentType=contentType, 
-			contentLength=os.path.getsize(localPath))
+			contentLength=os.path.getsize(localPath),
+			localSemantics=localSemantics)
 
 	def asDict(self):
 		"""returns the link definition in a form suitable for ingestion
@@ -397,7 +407,8 @@ class LinkDef(object):
 			"description": self.dlRow["description"],
 			"semantics": self.dlRow["semantics"],
 			"content_type": self.dlRow["contentType"],
-			"content_length": self.dlRow["contentLength"]}
+			"content_length": self.dlRow["contentLength"],
+			"local_semantics": self.dlRow["localSemantics"]}
 
 
 class _ServiceDescriptor(object):
@@ -426,7 +437,7 @@ class _ServiceDescriptor(object):
 		This is a RESOURCE as required by Datalink.
 
 		linkIdTo is used to support data access descriptors embedded
-		in descovery queries.  It is the id of the column containing
+		in discovery queries.  It is the id of the column containing
 		the identifiers.  SSA can already provide this. 
 		"""
 		paramsByName, stcSpecs = {}, set()
@@ -622,7 +633,7 @@ class DataFunction(rscdef.ProcApp):
 class DataFormatter(rscdef.ProcApp):
 	"""A procedure application that renders data in a processed service.
 
-	These play the role of the renderer, which for datalink is ususally
+	These play the role of the renderer, which for datalink is usually
 	trivial.  They are supposed to take descriptor.data and return
 	a pair of (mime-type, bytes), which is understood by most renderers.
 
@@ -702,7 +713,7 @@ class DatalinkCoreBase(svcs.Core, base.ExpansionDelegator):
 		description="A parameter to one of the proc apps (data functions,"
 		" formatters) active in this datalink core; no specific relation"
 		" between input keys and procApps is supposed; all procApps are passed"
-		" all argments. Conventionally, you will write the input keys in"
+		" all arguments. Conventionally, you will write the input keys in"
 		" front of the proc apps that interpret them.",
 		copyable=True)
 
@@ -721,7 +732,7 @@ class DatalinkCoreBase(svcs.Core, base.ExpansionDelegator):
 			ucd="meta.id;meta.main",
 			multiplicity="multiple",
 			std=True,
-			description="The pubisher DID of the dataset of interest"))
+			description="The publisher DID of the dataset of interest"))
 
 		if self.inputTable is base.NotGiven:
 			self.inputTable = MS(svcs.InputTD, inputKeys=self.inputKeys)
@@ -734,7 +745,7 @@ class DatalinkCoreBase(svcs.Core, base.ExpansionDelegator):
 		super().completeElement(ctx)
 
 	def getMetaForDescriptor(self, descriptor):
-		"""returns a pair of linkDefs, inputKeys for a datalink desriptor
+		"""returns a pair of linkDefs, inputKeys for a datalink descriptor
 		and this core.
 		"""
 		linkDefs, inputKeys, errors = [], self.inputKeys[:], []
