@@ -17,6 +17,7 @@ The RotatingFileHandler in this module tries to ensure this.
 import grp
 import os
 import warnings
+import logging
 from logging import handlers
 
 from gavo import base
@@ -48,3 +49,25 @@ class RotatingFileHandler(handlers.RotatingFileHandler):
 	def doRollover(self):
 		handlers.RotatingFileHandler.doRollover(self)
 		self._setOwnership()
+
+
+def getLoggingHandler(destName,
+		purpose,
+		maxBytes=500000,
+		backupCount=3,
+		mode=0o664):
+	"""returns a RotatingFileHandler for logging writing to destName.
+
+	If destName is not writable, then a plain StreamLogger is
+	returned.
+	"""
+	try:
+		return RotatingFileHandler(destName,
+			maxBytes=maxBytes,
+			backupCount=backupCount,
+			mode=mode,
+			encoding="utf-8")
+	except os.error:
+		warnings.warn(f"Cannot write to {destName}, using stderr for {purpose}."
+			"  Perhaps add yourself to the gavo group?")
+		return logging.StreamHandler()
