@@ -143,7 +143,7 @@ class _MoleculeMixin:
 
 			for hIso in range(1, 4):
 				totalWeight += atom.num_iso_H[hIso]*hIso
-			# no idea what the implict H-s should really count as.
+			# no idea what the implicit H-s should really count as.
 			totalWeight += atom.num_iso_H[0]
 		
 		return totalWeight
@@ -293,9 +293,9 @@ class _InChIBinding:
 			radical=0,
 			charge=ctypes.c_byte(charge))
 
-	def _handleAndFree(self, retval, output):
+	def _handleAndFree(self, retval, output, input=None):
 		try:
-			self._interpretICReturnCode(retval, output)
+			self._interpretICReturnCode(retval, output, input)
 			return utils.debytify(output.szInChI)
 		finally:
 			self._FreeStdINCHI(output)
@@ -308,21 +308,23 @@ class _InChIBinding:
 		5: "Previous call has not returned yet",
 		-1: "No structural data provided"}
 
-	def _interpretICReturnCode(self, retval, output):
+	def _interpretICReturnCode(self, retval, output, input=None):
 		if retval==1:
+			if input is not None:
+				warnings.warn("Source for the following warning: "+input)
 			warnings.warn("InChI warning: "+utils.debytify(output.szMessage))
 		elif retval!=0:
 			raise InChIError(utils.debytify(output.szMessage 
 					or self._errcodes.get(retval, "(Unclear problem)")),
 				hint=utils.debytify(output.szLog))
 
-	def getInChI(self, inchiInput):
+	def getInChI(self, inchiInput, rawInput=None):
 		"""returns the InChI of the molecule described through inchiInput
 		as a string.
 		"""
 		output = _inchi_Output()
 		res = self._GetStdINCHI(inchiInput, output)
-		return self._handleAndFree(res, output)
+		return self._handleAndFree(res, output, rawInput)
 
 	def normalizeInChI(self, inChI):
 		"""returns a string inChI in normalised form.
@@ -364,7 +366,7 @@ class _InChIBinding:
 		struct = _inchi_OutputStruct()
 		input = _inchi_InputINCHI(utils.bytify(inchi))
 		retval = self._GetStructFromINCHI(input, struct)
-		self._interpretICReturnCode(retval, struct)
+		self._interpretICReturnCode(retval, struct, inchi)
 
 		return self._freeStructAfterUse(struct)
 	
@@ -414,7 +416,7 @@ class _InChIBinding:
 		for bond_type, index1, index2 in connections:
 			mol.connect(index1-1, index2-1, bond_type)
 
-		return mol, self.getInChI(mol)
+		return mol, self.getInChI(mol, code)
 
 
 @functools.lru_cache(None)
