@@ -119,7 +119,7 @@ class CanonicalPrefixes(object):
 		"""sets up our canonical prefixes from DaCHS' (stanxml) namespace 
 		registry.
 		"""
-		from gavo import api  #noflake: hope most prefixes are registred after that
+		from gavo import api  #noflake: hope most prefixes are registered after that
 		from gavo.utils import stanxml
 		self._fillFromPairs(iter(stanxml.NSRegistry._registry.items()))
 		self._saveData()
@@ -603,7 +603,7 @@ class OAIQuery(object):
 		"""
 		res = self.doHTTP(verb=self.verb)
 		if not res.strip():
-			# empty reply is not admissable XML here
+			# empty reply is not admissible XML here
 			raise FailedQuery("Empty HTTP response")
 
 		handler = parserClass()
