@@ -6,7 +6,7 @@ There is a substantial overlap between what's going on there and datalink
 and scale things here shouldn't be developed on, all this should
 move towards datalink.  Meanwhile, we still have siapCutoutCore and
 friends that relies on the mess here, so all this is going to remain
-for the forseeable future.  Just don't extend it.
+for the foreseeable future.  Just don't extend it.
 
 The "user-visible" part are just accrefs, as modelled by the RAccref
 -- they can contain instructions for cutouts or scaling, hence the additional
@@ -20,7 +20,7 @@ synchronous iterData methods.  They must also work as t.w resources and thus
 have implement asynchronuous render(request) methods.  It's a bit unfortunate
 that we thus depend on t.w here, but we'd have to reimplement quite a bit of
 it if we don't, and for now it doesn't seem we'll support a different framework
-in the forseeable future.
+in the foreseeable future.
 """
 
 #c Copyright 2008-2022, the GAVO project <gavo@ari.uni-heidelberg.de>
@@ -86,7 +86,7 @@ def makePreviewFromFITS(product):
 					destSize=PREVIEW_SIZE)])
 	else:
 		raise NotImplementedError("TODO: Fix fitstools.iterScaledRows"
-			" to be more accomodating to weird things")
+			" to be more accommodating to weird things")
 	return imgtools.jpegFromNumpyArray(pixels)
 
 
@@ -230,7 +230,7 @@ class ProductBase(object):
 
 	The iterData method has to yield reasonably-sized chunks of
 	data (self.chunkSize should be a good choice).	It must be
-	synchronuous.
+	synchronous.
 
 	Products usually are used as t.w resources.  Therefore, they
 	must have a render method.	This must be asynchronuous,
@@ -737,7 +737,7 @@ class ProductCore(svcs.DBCore):
 	You will not usually mention this core in your RDs.  It is mainly
 	used internally to serve /getproduct queries.
 
-	It is instanciated from within //products.rd and relies on
+	It is instantiated from within //products.rd and relies on
 	tables within that RD.
 
 	The input data consists of accref; you can use the string form
@@ -752,7 +752,7 @@ class ProductCore(svcs.DBCore):
 	The core returns a list of instances of a subclass of ProductBase above.
 
 	This core and its supporting machinery handles all the fancy product
-	functionality (user autorisation, cutouts, ...).
+	functionality (user authorization, cutouts, ...).
 	"""
 	name_ = "productCore"
 
@@ -1008,7 +1008,14 @@ def makeProductLink(key, withHost=True, useHost=None):
 	the scheme part of the URI (e.g., ``split(":", 1)[-1]``).  In
 	data products served, DaCHS will then put in the scheme used
 	for the query.
+	
+	DaCHS (almost always) also allows full http URIs as accrefs.  These
+	will be returned unchanged.
 	"""
+	if hasattr(key, "startswith") and (
+			key.startswith("http://") or key.startswith("https://")):
+		return key
+
 	url = base.makeSitePath("/getproduct/%s"%RAccref.fromString(key))
 	if withHost:
 		if useHost is None:
