@@ -48,7 +48,7 @@ def getRadialCondition(td, ra, dec, sr,
 			decCol = td.getColumnByUCD("pos.eq.dec;meta.main")
 		else:
 			decCol = td.getColumnByName(decColName)
-	except ValueError:
+	except base.StructureError:
 		# presumably a UCD location failure
 		pointCols = td.getColumnsByUCD("pos.eq")
 		if pointCols:
@@ -163,7 +163,7 @@ class SCSCore(svcs.DBCore):
 		try:
 			self.idColumn = self.outputTable.getColumnByUCDs(
 				"meta.id;meta.main", "ID_MAIN")
-		except ValueError:
+		except base.StructureError:
 			base.ui.notifyWarning("SCS core at %s: Output table has no"
 				" meta.id;meta.main column.  This service will be invalid."%
 				self.getSourcePosition())
@@ -178,7 +178,7 @@ class SCSCore(svcs.DBCore):
 	def _guessDestPos(self, inputTable):
 		"""returns RA and Dec for a cone search possibly contained in inputTable.
 
-		If no positional query is discernable, this returns None.
+		If no positional query is discernible, this returns None.
 		"""
 		pars = inputTable.getParamDict()
 		if pars.get("RA") is not None and pars.get("DEC") is not None:
