@@ -37,17 +37,18 @@ GETDATA_FORMATS = {
 
 
 _SDM1_IRREGULARS = {
-	"Dataset.Type": "Spectrum.Type",
-	"Dataset.Length ": "Spectrum.Length",
-	"Dataset.TimeSI": "Spectrum.TimeSI",
-	"Dataset.SpectralSI": "Spectrum.SpectralSI",
-	"Dataset.FluxSI": "Spectrum.FluxSI",
-	"Access.Format": None,
-	"Access.Reference": None,
-	"Access.Size": None,
-	"AstroCoords.Position2D.Value2": 
+	"dataset.datamodel": "Spectrum.DataModel",
+	"dataset.type": "Spectrum.Type",
+	"dataset.length": "Spectrum.Length",
+	"dataset.timesi": "Spectrum.TimeSI",
+	"dataset.spectralsi": "Spectrum.SpectralSI",
+	"dataset.fluxsi": "Spectrum.FluxSI",
+	"access.format": None,
+	"access.reference": None,
+	"access.size": None,
+	"astrocoords.position2d.value2": 
 		"Spectrum.Char.SpatialAxis.Coverage.Location.Value",
-	"Target.pos.spoint": "Spectrum.Target.pos",
+	"target.pos.spoint": "Spectrum.Target.pos",
 }
 
 def getSDM1UtypeForSSA(utype):
@@ -63,7 +64,7 @@ def getSDM1UtypeForSSA(utype):
 	if utype is None:
 		return None
 	localName = utype.split(":")[-1]
-	specLocal = _SDM1_IRREGULARS.get(localName, "Spectrum."+localName)
+	specLocal = _SDM1_IRREGULARS.get(localName.lower(), "Spectrum."+localName)
 	if specLocal:
 		return "spec:"+specLocal
 	else:
@@ -100,8 +101,6 @@ def makeSDMDataForSSARow(ssaRow, spectrumData,
 	resData.setMeta("utype", "spec:Spectrum")
 
 	resTable = resData.getPrimaryTable()
-	resTable.setMeta("description",
-		"Spectrum from %s"%products.makeProductLink(ssaRow["accref"]))
 
 	# fudge accref into a full URL
 	resTable.setParam("accref",
@@ -110,8 +109,8 @@ def makeSDMDataForSSARow(ssaRow, spectrumData,
 
 	# fudge spoint params into 2-arrays
 	for param in resTable.iterParams():
-		# Bad, bad: In-place changes; we should think how such things
-		# can be done better in a rewrite
+		# Bad, bad: In-place changes; change this to creating new params
+		# one of these days.
 		if param.type=="spoint":
 			val = param.value
 			param.type = "double precision(2)"
@@ -128,7 +127,7 @@ def makeSDMDataForPUBDID(pubDID, ssaTD, spectrumData,
 	"""returns a rsc.Data instance containing an SDM compliant spectrum
 	for pubDID from ssaTable.
 
-	ssaTD is the definition of a table containg the SSA metadata, 
+	ssaTD is the definition of a table containing the SSA metadata, 
 	spectrumData is a data element making a primary table containing
 	the spectrum data from an SSA row (typically, this is going to be
 	the tablesource property of an SSA service).
@@ -193,7 +192,7 @@ def _make_limits_func(colUtype, keyBase):
 
 # A mapping from utypes to the corresponding FITS keywords
 # There are some more complex cases, for which a function is a value
-# here; the funciton is called with the FITS header and the parameter
+# here; the function is called with the FITS header and the parameter
 # in question.
 _SDM_HEADER_MAPPING = {
 	"datamodel": "VOCLASS",
@@ -406,7 +405,7 @@ def getFluxColumn(sdmTable):
 
 
 def getSpectralColumn(sdmTable):
-	"""returns the column containing the spectral coordindate in sdmTable.
+	"""returns the column containing the spectral coordinate in sdmTable.
 	"""
 	return sdmTable.tableDef.getByUtypes(
 		"spec:Spectrum.Data.SpectralAxis.Value")
@@ -459,7 +458,7 @@ def mangle_fluxcalib(sdmTable, newCalib):
 		# TODO: parameterize this
 		errorName = sdmTable.tableDef.getColumnByUCD(
 			"stat.error;phot.flux;em.opt").name
-	except ValueError:
+	except base.StructureError:
 		# no (known) error column
 		errorName = None
 
