@@ -125,7 +125,7 @@ class SSAPCore(svcs.DBCore):
 
 	previewColumn = base.parseFromString(svcs.OutputField,
 		'<outputField name="preview" type="text"'
-		' ucd="meta.ref.url;datalink.preview" tablehead="Preview"'
+		' ucd="meta.ref.url;meta.preview" tablehead="Preview"'
 		' description="URL of a preview for the dataset"'
 		' select="NULL" displayHint="type=product" verbLevel="15"/>')
 
