@@ -121,15 +121,15 @@ def _insertRDIntoTAP_SCHEMA(rd, connection):
 	
 	# finally, remove schemas that don't have any tables (which happens
 	# with adql-hidden tables, when moving RDs, etc.  Such leftovers
-	# are trouble because they're in TAP_SCHEMA but not in tables any more.
+	# are trouble because they're in TAP_SCHEMA but not in /tables any more.
 	connection.execute("""
-		delete from tap_schema.schemas 
-		where
-			schema_name in (
-				select schema_name 
-				from tap_schema.schemas 
-					left outer join tap_schema.tables using (schema_name) 
-				where table_name is null)""")
+		DELETE FROM tap_schema.schemas 
+		WHERE
+			schema_name IN (
+				SELECT schema_name 
+				FROM tap_schema.schemas 
+					LEFT OUTER JOIN tap_schema.tables USING (schema_name) 
+				WHERE table_name IS NULL)""")
 
 
 def publishToTAP(rd, connection):
