@@ -358,7 +358,7 @@ class CapabilityMaker(object):
 
 
 class PlainCapabilityMaker(CapabilityMaker):
-	"""A capability maker for gerneric VR.capabilities.
+	"""A capability maker for generic VR.capabilities.
 
 	These essentially just set standardId. in addition to what
 	the plain capabilities do.
@@ -592,7 +592,17 @@ class TAPCapabilityMaker(CapabilityMaker):
 								TR.form["COALESCE"],
 								TR.description["This is the standard SQL COALESCE"
 									" for providing defaults in case of NULL values."]],
+							TR.feature[
+								TR.form["VECTORMATH"],
+								TR.description["You can compute with vectors here. See"
+									" https://wiki.ivoa.net/twiki/bin/view/IVOA/ADQLVectorMath"
+									" for an overview of the functions and operators available."],
 							],
+							TR.feature[
+								TR.form["CASE"],
+								TR.description["The SQL92 CASE expression"],
+							],
+						],
 
 						TR.languageFeatures(
 								type="ivo://ivoa.net/std/TAPRegExt#features-adql-sets")[
