@@ -39,7 +39,7 @@ from gavo.registry import common
 # Names of renders that should not be shown to humans; these are
 # also not included in the dc.interfaces table.  Right now, this
 # list only contains the VOSI renderers, but other infrastructure-type
-# capabilites might belong here, too.
+# capabilities might belong here, too.
 HIDDEN_RENDERERS = frozenset([
 	'tableMetadata', 'availability', 'capabilities'])
 
@@ -159,9 +159,9 @@ def iterSvcRecs(service, keepTimestamp=False):
 			continue
 
 		try:
-			browseable = service.isBrowseableWith(pub.render)
+			browsable = service.isBrowseableWith(pub.render)
 		except AttributeError:  # service is not a ServiceBasedPage
-			browseable = False
+			browsable = False
 
 		pubService = service
 		if pub.service:
@@ -173,7 +173,7 @@ def iterSvcRecs(service, keepTimestamp=False):
 			"renderer": pub.render,
 			"accessURL":  pubService.getURL(pub.render, absolute=False),
 			"referenceURL": base.getMetaText(pubService, "referenceURL"),
-			"browseable": browseable,
+			"browseable": browsable,
 			"deleted": False}
 		yield ("interfaces", intfRec)
 
