@@ -57,16 +57,14 @@ def getForeignKeyForForeignKey(fk, namesInSet):
 	If the target table's name is not in nameInSet, the foreign key
 	is not created.
 	"""
-	targetName = fk.destTableName
-	if targetName not in namesInSet:
-		return None
-
-	return VS.foreignKey[
-		VS.targetTable[targetName], [
-			VS.fkColumn[
-				VS.fromColumn[fromColName.lower()],
-				VS.targetColumn[toColName.lower()]]
-			for fromColName,toColName in zip(fk.source, fk.dest)]]
+	targetName = fk.destTableName.lower()
+	if targetName in namesInSet:
+		return VS.foreignKey[
+			VS.targetTable[targetName], [
+				VS.fkColumn[
+					VS.fromColumn[fromColName.lower()],
+					VS.targetColumn[toColName.lower()]]
+				for fromColName,toColName in zip(fk.source, fk.dest)]]
 
 
 def getTableColumnFromColumn(column, typeFactory):
@@ -153,7 +151,7 @@ def _getObscoreStub():
 	"""
 	td = base.makeStruct(rscdef.TableDef, id="obscore",
 		parent_=base.caches.getRD("//obscore"))
-	td.setMeta("description", "This data collection is queriable in"
+	td.setMeta("description", "This data collection is queryable in"
 		" %s's obscore table."%base.getConfig("web", "sitename"))
 	return td
 
