@@ -103,7 +103,8 @@ void parseStringWithMagicNull(char *src, Field *field, int start, int len,
 	char *space, char *magic);
 void parseChar(char *src, Field *field, int srcInd);
 void real_fieldscanf(char *str, Field *f, valType type, char *fieldName, ...);
-size_t packFloatArray(unsigned char *buf, float *vals, int nVals);
+size_t packArray(unsigned char *buf, unsigned char *vals, int nVals,
+	int itemoid, size_t itemsize, int littleEndian);
 
 int degToDms(double deg, char *sign_out,
 	int *degs_out, int *minutes_out, double *seconds_out);
