@@ -170,7 +170,7 @@ class _DataFeeder(table._Feeder):
 		the exception.
 
 		If all went well and we control a connection, we commit it (unless
-		clients explicitely forbid it).
+		clients explicitly forbid it).
 		"""
 		affected = []
 		for feeder in self.feeders:
@@ -201,7 +201,7 @@ class _DataFeeder(table._Feeder):
 class Data(base.MetaMixin, common.ParamMixin):
 	"""A collection of tables.
 
-	``Data``, in essence, is the instanciation of a ``DataDescriptor``.
+	``Data``, in essence, is the instantiation of a ``DataDescriptor``.
 
 	It is what ``makeData`` returns.  In typical one-table situations, 
 	you just want to call the ``getPrimaryTable()`` method to obtain the
@@ -509,7 +509,7 @@ def makeData(dd, parseOptions=common.parseNonValidating,
 	You can pass in a data instance created by yourself in data.  This
 	makes sense if you want to, e.g., add some meta information up front.
 
-	makeData will ususally iterate over the sources given in dd.  You
+	makeData will usually iterate over the sources given in dd.  You
 	can override this with forceSource, which can contain a single
 	source passed to a grammar.  If you need to pass in multiple
 	sources, use a MultiForcedSources object (or anything that has
