@@ -2,7 +2,7 @@
 Tables on disk
 """
 
-#c Copyright 2008-2021, the GAVO project <gavo@ari.uni-heidelberg.de>
+#c Copyright 2008-2022, the GAVO project <gavo@ari.uni-heidelberg.de>
 #c
 #c This program is free software, covered by the GNU GPL.  See the
 #c COPYING file in the source distribution.
@@ -144,7 +144,6 @@ class MetaTableMixin(object):
 			"nrows": self.tableDef.nrows})
 
 	def addToMeta(self):
-		self.cleanFromMeta()  # Don't force people to clean first on meta updates
 		self._addToSourceTable()
 
 	def cleanFromMeta(self):
@@ -843,8 +842,11 @@ class View(DBTable):
 					self.tableDef.getSourcePosition(),
 					msg))
 
-	def importFinished(self, nImported):
+	def makeIndices(self):
 		if self.getTableType(self.tableDef.getQName())=="MATERIALIZED VIEW":
-			self.makeIndices()
+			super().makeIndices()
+
+	def importFinished(self, nImported):
+		self.makeIndices()
 		self.runScripts("postCreation")
 		return self
