@@ -8,7 +8,7 @@ import all grammars seemed quite a bit of waste, so how there's this
 manual registry.
 """
 
-#c Copyright 2008-2021, the GAVO project <gavo@ari.uni-heidelberg.de>
+#c Copyright 2008-2022, the GAVO project <gavo@ari.uni-heidelberg.de>
 #c
 #c This program is free software, covered by the GNU GPL.  See the
 #c COPYING file in the source distribution.
@@ -51,7 +51,7 @@ def getGrammar(grammarName):
 		raise base.NotFoundError(grammarName, "grammar", "defined grammars")
 	grammarClass = utils.loadInternalObject(*GRAMMAR_REGISTRY[grammarName])
 	if grammarClass.name_!=grammarName:
-		raise base.ReportableError("Internal Error: Grammar %s is registred"
+		raise base.ReportableError("Internal Error: Grammar %s is registered"
 			" under the wrong name."%grammarName,
 			hint="This is probably a typo in grammars.__init__; it needs"
 			" to be fixed there")
