@@ -283,10 +283,10 @@ class Values(base.Structure):
 	"""Information on a column's values, in particular its domain.
 
 	This is quite like the values element in a VOTable.  In particular,
-	to accomodate VOTable usage, we require nullLiteral to be a valid literal
+	to accommodate VOTable usage, we require nullLiteral to be a valid literal
 	for the parent's type.
 
-	Note that DaCHS does not validate for contraints from values on
+	Note that DaCHS does not validate for constraints from values on
 	table import.  This is mainly because before ``dachs limits`` has run,
 	values may not represent the new dataset in semiautomatic values.
 
@@ -547,7 +547,7 @@ class ColumnBase(base.Structure, base.MetaMixin):
 		" STC information for this column (do not assign to)",
 		default=None, copyable=True)
 	_dmRoles = DMRolesAttribute("dmRoles",
-		description="Roles played by this column; cannot be asigned to.")
+		description="Roles played by this column; cannot be assigned to.")
 	_properties = base.PropertyAttribute(copyable=True)
 	_original = base.OriginalAttribute()
 
@@ -635,7 +635,7 @@ class ColumnBase(base.Structure, base.MetaMixin):
 
 	def isIndexed(self):
 		"""returns a set of index kinds if this column is indexed, False if
-		it isn't or None if we don't know becasue we don't have a proper parent.
+		it isn't or None if we don't know because we don't have a proper parent.
 
 		In other words: it's a true value if the thing is indexed, a false
 		one if it is.  All further refinements are probably only there
@@ -681,6 +681,7 @@ class ColumnBase(base.Structure, base.MetaMixin):
 		"""
 		return {
 			"name": str(self.name),
+			"type": self.type,
 			"description": self.description or "N/A",
 			"tablehead": self.getLabel(),
 			"unit": self.unit or "N/A",
@@ -713,7 +714,7 @@ class ColumnBase(base.Structure, base.MetaMixin):
 		"""
 		if self.tablehead is not None:
 			return self.tablehead
-		return str(self.name).capitalize()
+		return str(self.key).capitalize()
 
 	def _getVOTableType(self):
 		"""returns the VOTable type, arraysize and xtype for this
@@ -789,7 +790,7 @@ class Column(ColumnBase):
 					self.values and self.values.nullLiteral):
 				try:
 					pos = codetricks.stealVar("context").pos
-					base.ui.notifyWarning("Somwhere near %s: "
+					base.ui.notifyWarning("Somewhere near %s: "
 						" Column %s may be null but has no explicit"
 						" null value."%(pos, self.name))
 				except (ValueError, AttributeError):
@@ -960,7 +961,6 @@ class ParamBase(ColumnBase):
 		The method also makes sure literal matches any constraints
 		set by a values child and raises a ValidationError if not.
 		"""
-
 		if self.type in self.unprocessedTypes:
 			return literal
 
