@@ -67,7 +67,7 @@ class RDAttribute(base.AttributeDef):
 		yield ("getFullId", getFullId)
 
 	def makeUserDoc(self):
-		return None   # don't metion it in docs -- users can't and mustn't set it.
+		return None   # don't mention it in docs -- users can't and mustn't set it.
 
 
 class ResdirRelativeAttribute(base.FunctionRelativePathAttribute):
@@ -382,17 +382,17 @@ class ColumnList(list):
 		return [item for item in self if item.ucd==ucd]
 
 	def getColumnByUCD(self, ucd):
-		"""retuns the single, unique column having ucd.
+		"""returns the single, unique column having ucd.
 
-		It raises a ValueError if there is no such column or more than one.
+		It raises a StructureError if there is no such column or more than one.
 		"""
 		cols = self.getColumnsByUCD(ucd)
 		if len(cols)==1:
 			return cols[0]
 		elif cols:
-			raise ValueError("More than one column for %s"%ucd)
+			raise base.StructureError("More than one column for %s"%ucd)
 		else:
-			raise ValueError("No column for %s"%ucd)
+			raise base.StructureError("No column for %s"%ucd)
 
 	def getColumnByUCDs(self, *ucds):
 		"""returns the single, unique column having one of ucds.
@@ -405,9 +405,10 @@ class ColumnList(list):
 		for ucd in ucds:
 			try:
 				return self.getColumnByUCD(ucd)
-			except ValueError:
+			except base.StructureError:  
+				# probably just no column with this UCD, try next
 				pass
-		raise ValueError("No unique column for any of %s"%", ".join(ucds))
+		raise base.StructureError("No unique column for any of %s"%", ".join(ucds))
 
 
 class ColumnListAttribute(base.StructListAttribute):
@@ -528,7 +529,7 @@ def getStandardPubDID(path):
 
 	The publisher dataset identifier (PubDID) is important in protocols like
 	SSAP and obscore.  If you use this function, the PubDID will be your
-	authority, the path compontent ~, and the inputs-relative path of 
+	authority, the path component ~, and the inputs-relative path of 
 	the input file as the parameter.
 
 	``path`` can be relative, in which case it is interpreted relative to
@@ -608,7 +609,7 @@ def getInputsRelativePath(absPath, liberalChars=True):
 	"""returns absath relative to the DaCHS inputsDir.
 
 	If ``absPath`` is not below ``inputsDir``, a ``ValueError`` results.  On 
-	``liberalChars``, wee see the `function getRelativePath`_.
+	``liberalChars``, we see the `function getRelativePath`_.
 
 	In rowmakers and rowfilters, you'll usually use the macro
 	``\inputRelativePath`` that inserts the appropriate code.
