@@ -150,7 +150,7 @@ class Coverage(base.Structure):
 		" of the resource")
 	
 	def completeElement(self, ctx):
-		self._completeElementNext(Coverage, ctx)
+		super().completeElement(ctx)
 
 		if self.spatial is base.NotGiven:
 			inj = ctx.getInjected("spatial_coverage", None)
