@@ -156,7 +156,7 @@ class Execute(base.Structure, base.ExpansionDelegator):
 		description="One or more hour:minute pairs at which to run"
 			" the code each day.  This conflicts with every.  Optionally,"
 			" you can prefix each time by one of m<dom> or w<dow> for"
-			" jobs only to be exectued at some day of the month or week, both"
+			" jobs only to be executed at some day of the month or week, both"
 			" counted from 1.  So, 'm22 7:30, w3 15:02' would execute on"
 			" the 22nd of each month at 7:30 UTC and on every wednesday at 15:02.",
 		default=base.NotGiven,
