@@ -58,7 +58,7 @@ class MixinPar(procdef.AliasableRDParameter):
 
 	_expr = base.DataContent(description="The default for the parameter."
 		" A __NULL__ here does not directly mean None/NULL, but since the"
-		" content will frequently end up in attributes, it will ususally work"
+		" content will frequently end up in attributes, it will usually work"
 		" as presetting None."
 		" An empty content means a non-preset parameter, which must be filled"
 		" in applications.  The magic value __EMPTY__ allows presetting an"
@@ -112,7 +112,7 @@ class MixinDef(activetags.ReplayBase):
 	Programmatically, you can check if a certain table mixes in 
 	something by calling its mixesIn method.
 
-	Recursive application of mixins, even to seperate objects, will deadlock.
+	Recursive application of mixins, even to separate objects, will deadlock.
 	"""
 	name_ = "mixinDef"
 
