@@ -146,7 +146,6 @@ class Keywords(argparse.Action):
 			return True
 
 		return not self.keywords-self._normalise(other)
-			
 
 
 ################## RD elements
@@ -314,7 +313,7 @@ class DataURL(base.Structure):
 	httpURL = "(not retrieved)"
 
 	_base = base.DataContent(description="Base for URL generation; embedded"
-		" whitespace will be removed, so you're free to break those whereever"
+		" whitespace will be removed, so you're free to break those wherever"
 		" you like.",
 		copyable=True)
 	
@@ -658,7 +657,7 @@ class RegTest(procdef.ProcApp, unittest.TestCase):
 				try:
 					foundVal = el.text
 				except AttributeError:
-					# assume the expression was for an attribute and just use teh
+					# assume the expression was for an attribute and just use the
 					# value
 					foundVal = el
 			else:
