@@ -251,7 +251,7 @@ class RowmakerMacroMixin(base.StandardMacroMixin):
 
 		The publisher dataset identifier (PubDID) is important in protocols like
 		SSAP and obscore.  If you use this macro, the PubDID will be your
-		authority, the path compontent ~, and the current value of @prodtblAccref.
+		authority, the path component ~, and the current value of @prodtblAccref.
 		It thus will only work where products#define (or a replacement) is in
 		action.  If it isn't, a normal function call
 		getStandardPubDID(\\inputRelativePath) would be an obvious alternative.
@@ -263,7 +263,7 @@ class RowmakerMacroMixin(base.StandardMacroMixin):
 	def macro_dlMetaURI(self, dlId):
 		"""returns a link to the datalink document for the current product.
 
-		This assumes you're assinging standard pubDIDs (see also standardPubDID,
+		This assumes you're assigning standard pubDIDs (see also standardPubDID,
 		which is used by this).
 
 		dlId is the XML id of the datalink service, which is supposed to
@@ -369,7 +369,7 @@ class RowmakerDef(base.Structure, RowmakerMacroMixin):
 
 	Rowmakers consist of variables, procedures and mappings.  They
 	result in a python callable doing the mapping.  In python code
-	withing rowmaker elements, you can use a large number of functions.
+	within rowmaker elements, you can use a large number of functions.
 	See `Functions available for row makers`_ in the reference documentation.
 
 	RowmakerDefs double as macro packages for the expansion of various
@@ -395,7 +395,7 @@ class RowmakerDef(base.Structure, RowmakerMacroMixin):
 	_rd = common.RDAttribute()
 	_idmaps = base.StringListAttribute("idmaps", description="List of"
 		' column names that are just "mapped through" (like map with key'
-		" only); you can use shell patterns to select multiple colums at once.",
+		" only); you can use shell patterns to select multiple columns at once.",
 		copyable=True)
 	_simplemaps = base.IdMapAttribute("simplemaps", description=
 		"Abbreviated notation for <map source>; each pair is destination:source", 
