@@ -125,7 +125,7 @@ class RD(base.Structure, base.ComputedMetaMixin, scripting.ScriptingMixin,
 
 	_procDefs = base.StructListAttribute("procDefs", 
 		childFactory=rscdef.ProcDef,
-		description="Procedure definintions (rowgens, rowmaker applys)",
+		description="Procedure definintions (rowgens, rowmaker apply-s)",
 		copyable=True, before="rowmakers")
 
 	_condDescs = base.StructListAttribute("condDescs", 
@@ -154,7 +154,7 @@ class RD(base.Structure, base.ComputedMetaMixin, scripting.ScriptingMixin,
 	_require = base.ActionAttribute("require", 
 		methodName="importModule",
 		description="Import the named gavo module (for when you need something"
-		" registred)")
+		" registered)")
 
 	_cores = base.MultiStructListAttribute("cores", 
 		childFactory=svcs.getCore, 
@@ -223,7 +223,7 @@ class RD(base.Structure, base.ComputedMetaMixin, scripting.ScriptingMixin,
 			if self.srcPath is not None:
 				return os.path.getmtime(self.srcPath)>self.loadedAt
 		except os.error:
-			# this will ususally mean the file went away
+			# this will usually mean the file went away
 			return True
 		return False
 
@@ -308,7 +308,7 @@ class RD(base.Structure, base.ComputedMetaMixin, scripting.ScriptingMixin,
 		"""declares that rd needs the RD prereq to properly work.
 
 		This is used in the generation of resource records to ensure that, e.g.
-		registred data have added their served-bys to the service resources.
+		registered data have added their served-bys to the service resources.
 		"""
 		if rd.sourceId!=prereq.sourceId:
 			self.rdDependencies.add((rd.sourceId, prereq.sourceId))
@@ -458,7 +458,7 @@ def canonicalizeRDId(srcId):
 	basically is "inputs-relative path without .rd extension".  Everything
 	that's not within inputs or doesn't end with .rd is handed through.
 	// is expanded to __system__/.  The path to built-in RDs,
-	/resources/inputs, is treated analoguous to inputsDir.
+	/resources/inputs, is treated analogous to inputsDir.
 	"""
 	if srcId.startswith("//"):
 		srcId = "__system__"+srcId[1:]
