@@ -32,7 +32,7 @@ from gavo.utils import DEG, ARCSEC
 # which makes building a Dijkstrable graph somewhat inconvenient.  So,
 # instead of striving for an optimal shortest path, we go for a
 # greedy search with some heuristics.  The most nonstandard feature is
-# that nodes are built ad-hoc and noncircularity of the paths thorugh
+# that nodes are built ad-hoc and noncircularity of the paths through
 # the "virtual" graph is checked on these ad-hoc nodes.
 
 # The nodes in the graph are triples of (system, equinox, refpos).  The
@@ -99,7 +99,7 @@ def _makeFindPath(transforms):
 	Each transform is a triple of (fromNode, toNode, transformFactory).
 
 	There's quite a bit of application-specific heuristics built in
-	here, so there's litte you can do with this code outside of
+	here, so there's little you can do with this code outside of
 	STC transforms construction.
 	"""
 	def findPath(fromTuple, toTuple, path=()):
@@ -163,7 +163,7 @@ def prec_IAU1976(fromEquinox, toEquinox):
 	This function is for the precTheory argument of getPrecMatrix.
 	"""
 	# time differences have to be in julian centuries
-	# captial T in Lieske
+	# capital T in Lieske
 	fromDiff = times.getSeconds(fromEquinox-times.dtJ2000)/common.secsPerJCy 
 	# lowercase T in Lieske
 	toDiff = times.getSeconds(toEquinox-fromEquinox)/common.secsPerJCy  
@@ -563,7 +563,7 @@ def _contractPrecessions(toContract):
 
 
 def _simplifyPath(path):
-	"""tries to simplify path by contracting mulitple consecutive precessions.
+	"""tries to simplify path by contracting multiple consecutive precessions.
 
 	These come in since our path finding algorithm sucks.  This is mainly
 	done for numerical reasons since the matrices would be contracted for
