@@ -14,8 +14,8 @@ Extensions to what the note says:
 		astroYear (Bnnnn, Jnnnn) designating a custom equinox.
 	- There is a system subphrase that lets you specify a system from the
 		STC library (without the ivo:// decoration).  It starts with System
-		and is specifed last.  It will override all other system specifications.
-	- If enabled, you can use identifiers in double quotes whereever values
+		and is specified last.  It will override all other system specifications.
+	- If enabled, you can use identifiers in double quotes wherever values
 		are allowed; this will generate column references.
 	- After the reference position, you can optionally mention the planetary
 		ephemeris used; currently, only JPL-DE200 and JPL-DE405 are allowed.
@@ -361,7 +361,7 @@ def _getSTCSGrammar(numberLiteral,
 
 # atomic "geometries"; I do not bother to specify their actual
 # arguments since, without knowing the frame, they may be basically
-# anthing.   Also, I want to allow geometry column references.
+# anything.   Also, I want to allow geometry column references.
 		_atomicGeometryKey = ( CaselessKeyword("AllSky").setName("sub-geometry")
 			| CaselessKeyword("Circle") 
 			| CaselessKeyword("Ellipse") 
