@@ -77,10 +77,10 @@ CORE_REGISTRY = {
 
 def getCore(name):
 	if name not in CORE_REGISTRY:
-		raise base.NotFoundError(name, "core", "registred cores")
+		raise base.NotFoundError(name, "core", "registered cores")
 	cls = utils.loadInternalObject(*CORE_REGISTRY[name])
 	if cls.name_!=name:
-		raise base.ReportableError("Internal Error: Core %s is registred"
+		raise base.ReportableError("Internal Error: Core %s is registered"
 			" under the wrong name."%name,
 			hint="This is probably a typo in svcs.core; it needs"
 			" to be fixed there")
@@ -100,8 +100,8 @@ class _OutputTableFactory(object):
 
 	def __call__(self, parent):
 		if parent._ot_prototype is None:
-			ot = outputdef.OutputTableDef(parent)
-			parent._ot_prototype = base.parseFromString(ot,
+			outputTD = outputdef.OutputTableDef(parent)
+			parent._ot_prototype = base.parseFromString(outputTD,
 				parent.outputTableXML or "<outputTable/>")
 		return parent._ot_prototype.copy(parent)
 
