@@ -204,7 +204,7 @@ class InputKey(column.ParamBase):
 		if self.multiplicity=="forced-single" and len(inputList)>1:
 			raise base.MultiplicityError(
 				"Inputs for the parameter %s must not have more than"
-				" one value; hovever, %s was passed in."%(
+				" one value; however, %s was passed in."%(
 					self.name,
 					str(inputList)),
 				colName=self.name)
@@ -454,7 +454,7 @@ class ContextGrammar(grammars.Grammar):
 	from request.strargs.
 
 	ContextGrammars never yield rows, so they're probably fairly useless
-	in normal cirumstances.
+	in normal circumstances.
 
 	In normal usage, they just yield a single parameter row,
 	corresponding to the source dictionary possibly completed with
