@@ -51,7 +51,7 @@ class OutputField(rscdef.Column):
 	_formatter = base.UnicodeAttribute("formatter", description="Function"
 		" body to render this item to HTML.", copyable=True, expand=True)
 	_wantsRow = base.BooleanAttribute("wantsRow", description="Does"
-		" formatter expect the entire row rather than the colum value only?",
+		" formatter expect the entire row rather than the column value only?",
 		copyable="True")
 	_select = base.UnicodeAttribute("select", description="Use this SQL"
 		" fragment rather than field name in the select list of a DB based"
@@ -216,7 +216,7 @@ class OutputTableDef(rscdef.TableDef):
 # TODO: we ought to somewhere have an API like 
 #
 # def getTableForQuery(td, colNames, whereClause, conn):
-#	ot = svcs.OutputTable.fromColumns(
+#	oTD = svcs.OutputTable.fromColumns(
 #		[td.getColumnByName(n) for n in colNames])
 #	return rsc.TableForDef(ot, rows
-#		=conn.queryToDicts(td.getSimpleQuery(ot, whereClause))
+#		=conn.queryToDicts(td.getSimpleQuery(oTD, whereClause))
