@@ -271,7 +271,7 @@ class PQLPar(object):
 	PQLPar objects have an attribute qualifier (None or a string),
 	and an attribute ranges, a list of PQLRange objects.
 	
-	As a client, you will ususally construct PQLPar objects using the
+	As a client, you will usually construct PQLPar objects using the
 	fromLiteral class method; it takes a PQL literal and a name to be 
 	used for LiteralParseErrors it may raise.
 
@@ -430,7 +430,7 @@ class PQLDatePar(PQLPar):
 
 	There's an additional complication here: in the database, dates can be
 	represented in various forms.  To save the day, getSQL takes an
-	additional optional parameter and transfroms the input values as
+	additional optional parameter and transforms the input values as
 	appropriate before passing them to the database.
 	"""
 	nullvalue = ""
@@ -443,7 +443,7 @@ class PQLDatePar(PQLPar):
 	def getSQL(self, colName, sqlPars, convert=None):
 		"""returns an SQL condition expressing the PQL constraint for colName.
 
-		In addition to the usual parameters, we here accept an additonal
+		In addition to the usual parameters, we here accept an additional
 		argument convert with possible values None (meaning timestamp, 
 		which is the default) mjd, jd, and jy, which represents how the 
 		datetimes are represented in the database.  
@@ -487,15 +487,15 @@ class PQLPositionPar(PQLPar):
 
 	def getSQL(self, colName, sqlPars):
 		raise NotImplementedError("Ranges for PQL POS not implemented yet.")
-	
-	def getConeSQL(self, colName, sqlPars, coneSize):
+
+	def _iterICRSPositions(self):
+		"""yields pairs of ICRS (ra, dec) from this condition.
+		"""
 		if self.qualifier and self.qualifier!='ICRS':
 			# XXX TODO: implement at least a couple of common frames
 			raise base.ValidationError("Cannot match against coordinates"
 				" given in %s frame"%self.qualifier, self.destName)
 
-		sizeName = base.getSQLKey("size", coneSize*DEG, sqlPars)
-		parts = []
 		if len(self.ranges)%2:
 			raise base.ValidationError("PQL position values must be lists of"
 				" length divisible by 2.", self.destName)
@@ -507,10 +507,31 @@ class PQLPositionPar(PQLPar):
 			if lastCoo is None:
 				lastCoo = r.value
 			else:
-				parts.append("%s <@ scircle(%%(%s)s, %%(%s)s)"%(colName,
-					base.getSQLKey("pos", pgsphere.SPoint.fromDegrees(lastCoo, r.value), 
-						sqlPars), sizeName))
+				yield (lastCoo, r.value)
 				lastCoo = None
+
+	def getConeSQL(self, colName, sqlPars, coneSize):
+		"""returns SQL to compute the constraint agains a pgsphere point column.
+		"""
+		sizeName = base.getSQLKey("size", coneSize*DEG, sqlPars)
+		parts = []
+		for ra, dec in self._iterICRSPositions():
+			parts.append("%s <@ scircle(%%(%s)s, %%(%s)s)"%(colName,
+				base.getSQLKey("pos", pgsphere.SPoint.fromDegrees(ra, dec), 
+					sqlPars), sizeName))
+		return "(%s)"%" OR ".join(parts)
+
+	def getQ3CSQL(self, raCol, decCol, sqlPars, coneSize):
+		"""returns SQL to compute the constraint agains a pgsphere point column.
+		"""
+		sizeName = base.getSQLKey("size", coneSize, sqlPars)
+		parts = []
+		for ra, dec in self._iterICRSPositions():
+			parts.append("q3c_radial_query({}, {}, %({})s, %({})s, %({})s)".format(
+				raCol, decCol, 
+				base.getSQLKey("ra", ra, sqlPars),
+				base.getSQLKey("dec", dec, sqlPars),
+				sizeName))
 		return "(%s)"%" OR ".join(parts)
 
 	def covers(self, value):
