@@ -262,7 +262,7 @@ class CustomDF(CustomPageFunction):
 	You can use the request to fetch request parameters.  Within DaCHS,
 	in addition to the clumsy request.args (mapping bytes to bytes), there
 	is also request.strargs (mapping strings to strings).  So, access a 
-	query paramter ``order`` like this::
+	query parameter ``order`` like this::
 
 		sortOrder = ctx.request.strargs.get("order", ["authors"])
 	"""
@@ -274,7 +274,7 @@ class CoreAttribute(base.ReferenceAttribute):
 		base.ReferenceAttribute.__init__(self, "core", 
 			description="The core that does the computations for this service."
 			"  Instead of a reference, you can use an immediate element"
-			" of some registred core.", 
+			" of some registered core.", 
 			forceType=core.Core, copyable=True, aliases=list(core.CORE_REGISTRY.keys()))
 	
 	def _makeChild(self, name, parent):
@@ -344,7 +344,7 @@ class Service(base.Structure, base.ComputedMetaMixin,
 		description="resdir-relative path to custom page code.  It is used"
 		" by the 'custom' renderer", copyable="True")
 	_allowedRenderers = base.StringSetAttribute("allowed",
-		description="Names of renderers allowed on this service; leave emtpy"
+		description="Names of renderers allowed on this service; leave empty"
 		" to allow the form renderer only.", copyable=True)
 	_customRF = base.StructListAttribute("customRFs",
 		description="Custom render functions for use in custom templates.",
@@ -517,7 +517,7 @@ class Service(base.Structure, base.ComputedMetaMixin,
 	def _iterAutomaticCapabilities(self):
 		"""helps _addAutomaticCapabilities.
 
-		Actually, we also use it to generate VOSI capabilties for
+		Actually, we also use it to generate VOSI capabilities for
 		unpublished services.
 		"""
 		vosiSet = set(["ivo_managed"])
@@ -775,7 +775,7 @@ class Service(base.Structure, base.ComputedMetaMixin,
 	_allSet = set(["ALL"])
 
 	def _getFilteredColumns(self, columnSource, queryMeta, verbLevel):
-		"""filters columns in columnSource according to verbosity and colum
+		"""filters columns in columnSource according to verbosity and column
 		set given in queryMeta.
 
 		Actually, we only evaluate verbosity and requireSet.
@@ -923,7 +923,7 @@ class Service(base.Structure, base.ComputedMetaMixin,
 		return self._coresCache[renderer.name]
 
 	def getContextGrammarFor(self, renderer, queryMeta, core=None):
-		"""returns an ContextGrammar apropriate for this renderer.
+		"""returns an ContextGrammar appropriate for this renderer.
 
 		Pass in the core if you already have it as an optimisation (in
 		particular for datalink, where cores aren't automatically cached);
