@@ -288,6 +288,13 @@ def updateTAPSchema(querier, args):
 			base.ui.notifyWarning("Stale records in TAP_SCHEMA: %s"%msg)
 
 
+@exposedFunction([Arg(help="Password to hash", dest="pw")], 
+	help="Hash a password (typically for [web]adminpasswd)")
+def hashPasswd(querier, args):
+	from gavo.protocols import creds
+	print(creds.hashPassword(args.pw))
+
+
 def main():
 	with base.AdhocQuerier(lambda: base.getDBConnection("feed")) as querier:
 		args = makeCLIParser(globals()).parse_args()
