@@ -2,7 +2,7 @@
 The main entry point to CLI usage of GAVO code.
 """
 
-#c Copyright 2008-2021, the GAVO project <gavo@ari.uni-heidelberg.de>
+#c Copyright 2008-2022, the GAVO project <gavo@ari.uni-heidelberg.de>
 #c
 #c This program is free software, covered by the GNU GPL.  See the
 #c COPYING file in the source distribution.
@@ -56,7 +56,7 @@ functions = [
 	("upgrade", ("user.upgrade", "main")),
 	("uwsrun", ("protocols.useruws", "main")),
 # init is special cased, but we want it in here for help generation
-	("init", ("initdachs.info", "main")),
+	("init", ("user.initdachs", "main")),
 ]
 
 
