@@ -163,7 +163,7 @@ def raiseAndCatch(opts=None, output=outputError):
 			messages.append("While executing DB query:\n")
 			messages.append("  "+utils.debytify(msg.cursor.query))
 		messages.append("\nThe database engine reported:\n")
-		messages.append("  "+utils.debytify(msg.pgerror or b"(Nothing)"))
+		messages.append("  "+utils.debytify(msg.pgerror or msg.args[0]))
 
 	else:
 		if hasattr(msg, "excRow"):
