@@ -360,12 +360,16 @@ def _loadPgExtension(conn, extName):
 
 
 def _doLocalSetup(dsn):
-	"""executes some commands that need to be executed with superuser
-	privileges.
-	"""
 # When adding stuff here, fix docs/install.rstx, "Owner-only db setup"
+	from gavo.base import config
+	feedProfile = config.getDBProfile("feed")
+	
 	conn = psycopg2.connect(dsn.full)
 	for statement in [
+      # gavoadmin/feed can create public functions and similar; perhaps
+      # we need to think again if we should put them somewhere else.
+      # cf. https://www.postgresql.org/docs/15/ddl-schemas.html#DDL-SCHEMAS-PATTERNS
+      f"GRANT ALL ON SCHEMA public TO {feedProfile.user}",
 			"CREATE OR REPLACE LANGUAGE plpgsql"]:
 		cursor = conn.cursor()
 		try:
@@ -429,6 +433,12 @@ def initDB(dsn):
 	_createRoles(dsn)
 	_doLocalSetup(dsn)
 	_readDBScripts(dsn)
+
+	# Un-init the db connection to re-read any functions that may
+	# have been created by anything up to here.
+	from gavo.base import sqlsupport
+	sqlsupport._PSYCOPG_INITED = False
+	sqlsupport._initPsycopg()
 	_importBasicResources()
 
 
