@@ -18,7 +18,7 @@ import traceback
 from gavo import base
 from gavo import utils
 from gavo.base import ObserverBase, listensTo
-from gavo.protocols.gavolog import RotatingFileHandler
+from gavo.protocols.gavolog import getLoggingHandler
 
 
 def stringify(s):
@@ -53,18 +53,18 @@ class LoggingUI(ObserverBase):
 
 	def __init__(self, eh, errorName="dcErrors", infoName="dcInfos"):
 		ObserverBase.__init__(self, eh)
-		errH = RotatingFileHandler(
-			os.path.join(base.getConfig("logDir"), errorName),
-			maxBytes=500000, backupCount=3, mode=0o664, encoding="utf-8")
+		errH = getLoggingHandler(
+			os.path.join(base.getConfig("logDir"), errorName), "errors")
 		errH.setFormatter(
 			logging.Formatter(self.logLineFormat))
 		self.errorLogger = logging.getLogger("dcErrors")
 		self.errorLogger.addHandler(errH)
 		self.errorLogger.propagate = False
 
-		infoH = RotatingFileHandler(
-			os.path.join(base.getConfig("logDir"), infoName),
-			maxBytes=500000, backupCount=1, mode=0o664, encoding="utf-8")
+		infoH = getLoggingHandler(
+		  os.path.join(base.getConfig("logDir"), infoName),
+		  "infos",
+		  backupCount=1)
 		infoH.setFormatter(logging.Formatter(self.logLineFormat))
 		self.infoLogger = logging.getLogger("dcInfos")
 		self.infoLogger.propagate = False
