@@ -43,7 +43,7 @@ MS = base.makeStruct
 FT_TYPE_MAP = {
 	"L": "boolean",
 	"B": "bytea",
-	"A": "text",
+	"A": "char",
 	"I": "smallint",
 	"J": "integer",
 	"K": "bigint",
@@ -52,6 +52,38 @@ FT_TYPE_MAP = {
 }
 
 
+def getTypeForFTFormat(format, name):
+	"""returns a DaCHS type for FITS table column.
+	"""
+	typeCode = None
+
+	# variable-length array FITS codes
+	mat = re.match("(\d*)P(.)\(\d*\)$", format)
+	if mat:
+		typeCode = mat.group(2)
+		arrSize = "100"  # just a sentinel
+
+	# "conventional FITS codes
+	else:
+		mat = re.match("(\d*)(.)$", format)
+		if mat:
+			arrSize, typeCode = mat.group(1), mat.group(2)
+
+	if typeCode not in FT_TYPE_MAP:
+		raise base.ReportableError(f"FITS type code '{format}' of {name}"
+			" not handled by gavo mkrd; add handling if you can.")
+
+	dbType = FT_TYPE_MAP[typeCode]
+	if arrSize and int(arrSize)>1:
+		if dbType=="char":
+			dbType = "text"
+		else:
+			dbType = dbType+"[]"
+
+	return dbType
+
+
+
 # ======================= Begin deprecated ui and implementation ===========
 
 ignoredFITSHeaders = set(["COMMENT", "SIMPLE", "BITPIX", "EXTEND", 
@@ -103,19 +135,6 @@ def structToETree(aStruct):
 	return nodeStack[-1]
 
 
-def getTypeForFTFormat(format, name):
-	"""returns a DaCHS type for FITS table column.
-
-	This currently ignores array sizes and such.  Well, people can always
-	fix things manually.
-	"""
-	mat = re.match("(\d*)(.)$", format)
-	if not mat or not mat.group(2) in FT_TYPE_MAP:
-		raise base.ReportableError("FITS type code '%s' of %s not handled"
-			" by gavo mkrd; add handling if you can."%(format, name))
-	return FT_TYPE_MAP[mat.group(2)]
-
-
 def makeTableFromFT(rd, srcName, opts):
 	from gavo.utils import pyfits
 	cols, nameMaps = [], {}
@@ -499,7 +518,7 @@ def iterColAttrsViz(inFile, dumpRanges=False):
 	"""tries to parse (text) inFile as a VizieR-Style bytes-by-bytes
 	description and yields colAttrs for the first described table.
 
-	dumpRanges is for interactiv use, where the function additionally
+	dumpRanges is for interactive use, where the function additionally
 	dumps a colDefs content to stdout.
 	"""
 	parser = VizBBBParser()
