@@ -17,9 +17,8 @@ import signal
 import subprocess
 import sys
 import time
-import urllib.request, urllib.parse, urllib.error
+import urllib.parse
 import warnings
-from urllib.parse import urlparse
 
 from twisted.internet import reactor
 from twisted.internet import task
@@ -573,8 +572,9 @@ def expireRDs(args):
 					{"rdId":rdId, "__nevow_form__": "genForm", "submit": "Go"})),
 				creds=("gavoadmin", pw))
 			ignored = f.read()  #noflake: don't care enough to check at this point.
-		except IOError as msg:
-			raise base.ReportableError("Failed to reload %s: %s"%(rdId, msg))
+		except IOError:
+			raise base.ReportableError(
+				f"Failed to reload {rdId} -- have you set the admin password?")
 
 
 @exposedFunction([], help="Create or renew a letsencrypt certificate"
@@ -589,7 +589,7 @@ def updateCertificate(args):
 
 	# to make a CSR for the host names we're known as, first write an
 	# openssl cfg...
-	names = [urlparse(config.get("web", "serverURL")).hostname
+	names = [urllib.parse.urlparse(config.get("web", "serverURL")).hostname
 		]+base.getConfig("web", "alternateHostnames")
 	with open("dachs.conf", "wb") as f:
 		f.write(b"[req]\ndefault_bits=4096\n"
