@@ -32,7 +32,7 @@ from gavo import rscdesc  #noflake: for cache registration
 from gavo import utils
 
 
-CURRENT_SCHEMAVERSION = 32
+CURRENT_SCHEMAVERSION = 33
 
 
 class _COMMIT(object):
@@ -64,9 +64,14 @@ def _updateTAP_SCHEMA(connection):
 
 	toDo = [r[0] for r in 
 		connection.query(
-			"SELECT DISTINCT sourceRD FROM dc.tablemeta")]
+			"SELECT DISTINCT sourceRD FROM tap_schema.tables")]
 
 	for rdId in toDo:
+		if rdId=="__system__/tap":
+			# TAP_SCHEMA needs special handling because of bootstrapping
+			tap._insertRDIntoTAP_SCHEMA(base.caches.getRD(rdId), connection)
+			continue
+
 		try:
 			tap.publishToTAP(
 				base.caches.getRD(rdId, doQueries=False), connection)
@@ -465,7 +470,7 @@ class To11Upgrader(Upgrader):
 							).exists():
 						continue
 
-					# table needs re-importing, see if you can find a correponsing 
+					# table needs re-importing, see if you can find a corresponding 
 					# data element
 					for dd in rd.dds:
 						for make in dd.makes:
@@ -909,6 +914,22 @@ class To32Upgrader(Upgrader):
 			rsc.makeData(dd, connection=connection)
 
 
+class To33Upgrader(Upgrader):
+	version = 32
+
+	@classmethod
+	def s_010_add_nrows_in_tap_schema(cls, connection):
+		"""adding nrows to tap_schema.tables"""
+		if "nrows" not in getColumnNamesFor("//tap#tables", connection):
+			connection.execute("ALTER TABLE tap_schema.tables"
+				" ADD COLUMN nrows BIGINT")
+
+	@classmethod
+	def u_020_fill_tap_schema(cls, connection):
+		"""updating tap_schema to include nrows"""
+		_updateTAP_SCHEMA(connection)
+
+
 def iterStatements(startVersion, endVersion=CURRENT_SCHEMAVERSION, 
 		upgraders=None):
 	"""yields all upgraders from startVersion to endVersion in sequence.
