@@ -88,7 +88,8 @@ from gavo.utils.texttricks import (formatSize, formatFloat,
 	getFileStem,
 	fixIndentation, parsePercentExpression, hmsToDeg, dmsToDeg,
 	makeIAUId,
-	fracHoursToDeg, degToHms, degToDms, getRelativePath, parseAssignments, 
+	fracHoursToDeg, degToHms, degToDms, hoursToHms,
+	getRelativePath, parseAssignments, 
 	NameMap, formatSimpleTable, replaceXMLEntityRefs,
 	ensureOneSlash, getRandomString,
 	safe_str, defuseFileName, bytify, debytify, iterSimpleText)
