@@ -145,7 +145,7 @@ class IdManagerMixin(object):
 	"""
 	A mixin for objects requiring unique IDs.
 	
-	The primaray use case is XML generation, where you want stable IDs
+	The primary use case is XML generation, where you want stable IDs
 	for objects, but IDs must be unique over an entire XML file.
 	
 	The IdManagerMixin provides some methods for doing that:
@@ -271,7 +271,7 @@ class _CmpType(type):
 class _Comparer(object, metaclass=_CmpType):
 	def __init__(self, *args, **kwargs):
 		raise excs.Error(
-			"%s classes can't be instanciated."%self.__class__.__name__)
+			"%s classes can't be instantiated."%self.__class__.__name__)
 
 
 class Infimum(_Comparer):
@@ -451,7 +451,7 @@ def sandbox(tmpdir=None, debug=False, extractfunc=None):
 	directory is the sandbox created while in the controlled block.
 
 	If tmpdir is None, the *system* default is used (usually /tmp),
-	rather than dachs' tmpdir.  So, you will ususally want to call
+	rather than dachs' tmpdir.  So, you will usually want to call
 	this as sandbox(base.getConfig("tempDir"))
 
 	This is obviously not thread-safe -- you'll not usually want
