@@ -72,7 +72,7 @@ try:
 		You can pass in a full role function as discussed in
 		/usr/share/doc/python-docutils/docs/howto/rst-roles.html (Debian systems).
 		It must, however, add a dachs-ex-<roleName> class to the node. The
-		default funtion produces a nodes.emphasis item with the proper class.
+		default function produces a nodes.emphasis item with the proper class.
 
 		In a pinch, you can pass a propertyName argument to addRole if the
 		desired property name is distinct from the role name in the RST.
@@ -106,7 +106,7 @@ try:
 		
 		@classmethod
 		def _makeDefaultRoleFunc(cls, roleName):
-			"""returns an RST interpeted text role parser function returning
+			"""returns an RST interpreted text role parser function returning
 			an emphasis node with a dachs-ex-roleName class.
 			"""
 			def roleFunc(name, rawText, text, lineno, inliner, 
@@ -131,7 +131,7 @@ try:
 	RSTExtensions.makeTextRole("bibcode", _bibcodeRoleFunc)
 	del _bibcodeRoleFunc
 
-	# RST extensions for documention writing
+	# RST extensions for documentation writing
 
 	_explicitTitleRE = re.compile(r'^(.+?)\s*(?<!\x00)<(.*?)>$', re.DOTALL)
 
@@ -513,7 +513,7 @@ def getFortranRec(f):
 	"""reads a "fortran record" from f and returns the payload.
 
 	A "fortran record" comes from an unformatted file and has a
-	4-byte payload length before and after the payload.  Native endianess
+	4-byte payload length before and after the payload.  Native endianness
 	is assumed here.
 
 	If the two length specs do not match, a ValueError is raised.
@@ -559,7 +559,7 @@ def getWithCache(url, cacheDir, extraHeaders={}):
 	"""returns the content of url, from a cache if possible.
 
 	Of course, you only want to use this if there's some external guarantee
-	that the resource behing url doesn't change.  No expiry mechanism is
+	that the resource behind url doesn't change.  No expiry mechanism is
 	present here.
 	"""
 	if not os.path.isdir(cacheDir):
