@@ -1,5 +1,5 @@
 """
-Bindings for the pgsphere libarary and psycopg2.
+Bindings for the pgsphere library and psycopg2.
 
 Basically, once per program run, you need to call preparePgSphere(connection),
 and you're done.
@@ -63,7 +63,7 @@ class PgSAdapter(object):
 	``_adaptToPgSphere(obj)`` and ``_castFromPgSphere(value, cursor)``.
 
 	You must also define a sequence checkedAttributes; all attributes
-	metioned there must be equal for two adapted values to be equal (equality
+	mentioned there must be equal for two adapted values to be equal (equality
 	testing here really is mainly for unit tests with hand-crafted values).
 
 	Also, all subclasses you should provide an asPoly returning a spherical
@@ -315,7 +315,7 @@ class SPoly(PgSAdapter):
 			return None
 		if len(daliSeq)<6 or len(daliSeq)%2:
 			raise ValueError("Need an even-numbered number (>=6) of floats"
-				" in a DALI polygon represenation, got %s floats."%len(daliSeq))
+				" in a DALI polygon representation, got %s floats."%len(daliSeq))
 
 		return cls([SPoint.fromDegrees(*tuple(p)) 
 			for p in misctricks.grouped(2, daliSeq)])
