@@ -45,7 +45,7 @@ class _Autoconstructor(autonode.AutoNodeType):
 	"""A metaclass used for Elements.
 
 	On the one hand, it does autonode's constructor magic with _a_<attrname>
-	attributes, on the other, it will instanciate itself when indexed
+	attributes, on the other, it will instantiate itself when indexed
 	-- that we want for convenient stan-like notation.
 	"""
 	def __init__(cls, name, bases, dict):
@@ -321,7 +321,7 @@ class Element(object, metaclass=_Autoconstructor):
 			yield name, xmlName
 
 	def addAttribute(self, attName, attValue):
-		"""adds attName, attValue to this Element's attributes when instanciated.
+		"""adds attName, attValue to this Element's attributes when instantiated.
 
 		You cannot add _a_<attname> attributes to instances.  Thus, when
 		in a pinch, use this.
@@ -407,7 +407,7 @@ class NSRegistry(object):
 
 	This is used to have fixed namespace prefixes (IMHO the only way
 	to have namespaced attribute values and retain sanity).  The
-	class is never instanciated.  It is used through the module-level
+	class is never instantiated.  It is used through the module-level
 	method registerPrefix.
 	"""
 	_registry = {}
