@@ -10,7 +10,6 @@ Formatting, text manipulation, string constants, and such.
 import calendar
 import datetime
 import functools
-import math
 import os
 import quopri
 import random
@@ -19,6 +18,13 @@ import string
 import time
 from email import utils as emailutils
 
+try:
+	from astropy.coordinates import angle_formats
+except ImportError:
+	# old astropy
+	from astropy.coordinates import angle_utilities as angle_formats
+
+
 from gavo.utils import codetricks
 from gavo.utils import misctricks
 from gavo.utils.excs import SourceParseError, StructureError
@@ -87,7 +93,7 @@ def makeLeftEllipsis(aStr, maxLen=60):
 def makeSourceEllipsis(sourceToken):
 	"""returns a string hopefully representative for a source token.
 
-	These are, in particular, passed around withing rsc.makeData.  Usually,
+	These are, in particular, passed around within rsc.makeData.  Usually,
 	these are (potentially long) strings, but now and then they can be
 	other things with appallingly long reprs.  When DaCHS messages
 	need to refer to such sources, this function is used to come up
@@ -259,7 +265,7 @@ def parsePercentExpression(literal, format):
 	allowed.  Each conversion is allowed to contain zero or more characters
 	matched stingily.  Successive conversions without intervening literals
 	aren't really supported.  There's a hack for strptime-type times, though:
-	H, M, and S just eat two characters each if there's no seperator.
+	H, M, and S just eat two characters each if there's no separator.
 	
 	This is really only meant as a quick hack to support times like 25:33.
 
@@ -283,7 +289,7 @@ def parseAssignments(assignments):
 
 	This is the preferred form of communicating a mapping from external names
 	to field names in records to macros -- in a string that contains
-	":"-seprated pairs seperated by whitespace, like "a:b  b:c", where
+	":"-seprated pairs separated by whitespace, like "a:b  b:c", where
 	the incoming names are leading, the desired names are trailing.
 
 	If you need defaults to kick in when the incoming data is None, try
@@ -379,44 +385,6 @@ def fracHoursToDeg(fracHours):
 	return float(fracHours)*360./24.
 
 
-def _formatSecs(seconds, secondFracs, truncate):
-	"""returns a string representation of the float seconds with secondFracs
-	fractionals.
-
-	With truncate=True, we truncate rather than round.
-
-	Behaviour with negative seconds is undefined for now (let's see if
-	we ever need that).
-	>>> _formatSecs(0, 0, False)
-	'00'
-	>>> _formatSecs(0, 1, False)
-	'00.0'
-	>>> _formatSecs(3.689, 2, False)
-	'03.69'
-	>>> _formatSecs(3.689, 1, False)
-	'03.7'
-	>>> _formatSecs(3.689, 0, False)
-	'04'
-	>>> _formatSecs(3.689, 2, True)
-	'03.68'
-	>>> _formatSecs(3.689, 1, True)
-	'03.6'
-	>>> _formatSecs(3.689, 0, True)
-	'03'
-	"""
-	if truncate:
-		fracPart, intPart = math.modf(seconds)
-		secPart = "%02d"%int(intPart)
-		if secondFracs>0:
-			secPart += ("%019.17f"%fracPart)[1:secondFracs+2]
-	else:
-		if secondFracs<1:
-			secondFracs = -1
-		secPart = "%0*.*f"%(secondFracs+3, secondFracs, seconds)
-	
-	return secPart
-
-
 @codetricks.document
 def degToHms(deg, 
 		sepChar=" ", 
@@ -431,8 +399,8 @@ def degToHms(deg,
 	* truncate can be set to True if fractional seconds should be truncated
 	  rather then rounded (as necessary for building IAU identifiers)
 
-	>>> degToHms(0)
-	'00 00 00.000'
+	>>> degToHms(0, sepChar=":")
+	'00:00:00.000'
 	>>> degToHms(122.057, secondFracs=1)
 	'08 08 13.7'
 	>>> degToHms(122.057, secondFracs=1, truncate=True)
@@ -443,22 +411,45 @@ def degToHms(deg,
 	'-00 00 13'
 	>>> degToHms(-1.056, secondFracs=0)
 	'-00 04 13'
+	>>> degToHms(-1.056, secondFracs=0)
+	'-00 04 13'
+	>>> degToHms(359.9999999)
+	'24 00 00.000'
 	>>> degToHms(359.2222, secondFracs=4, sepChar=":")
 	'23:56:53.3280'
 	>>> "%.4f"%hmsToDeg(degToHms(256.25, secondFracs=9))
 	'256.2500'
 	"""
-	sign = ""
-	if deg<0:
-		sign = "-"
-		deg = -deg
-	rest, hours = math.modf(deg/360.*24)
-	rest, minutes = math.modf(rest*60)
+	if truncate:
+		return angle_formats.hours_to_string(
+			deg/360*24, sep=(sepChar, sepChar), 
+			precision=secondFracs+8, pad=True)[:-8].rstrip(".")
 
-	return sign+sepChar.join([
-		"%02d"%int(hours), 
-		"%02d"%abs(int(minutes)), 
-		_formatSecs(abs(rest*60), secondFracs, truncate)])
+	return angle_formats.hours_to_string(
+		deg/360*24, sep=(sepChar, sepChar), precision=secondFracs, pad=True)
+
+
+@codetricks.document
+def hoursToHms(decimal_hours, sepChar=":", secondFracs=0):
+	"""returns a time span in hours in sexagesmal time (h:m:s).
+
+	The optional argments are as for degToHms.
+
+	>>> hoursToHms(0)
+	'00:00:00'
+	>>> hoursToHms(23.5)
+	'23:30:00'
+	>>> hoursToHms(23.55)
+	'23:33:00'
+	>>> hoursToHms(23.525)
+	'23:31:30'
+	>>> hoursToHms(23.553, secondFracs=2)
+	'23:33:10.80'
+	>>> hoursToHms(123.553, secondFracs=2)
+	'123:33:10.80'
+	"""
+	return angle_formats.hours_to_string(
+		decimal_hours, sep=(sepChar, sepChar), precision=secondFracs, pad=True)
 
 
 @codetricks.document
@@ -466,7 +457,8 @@ def degToDms(deg,
 		sepChar=" ", 
 		secondFracs=2, 
 		preserveLeading=False,
-		truncate=False):
+		truncate=False,
+		addSign=True):
 	"""converts a float angle in degrees to a sexagesimal string.
 
 	This takes a lot of optional arguments:
@@ -477,36 +469,36 @@ def degToDms(deg,
 	  preserved
 	* truncate can be set to True if fractional seconds should be truncated
 	  rather then rounded (as necessary for building IAU identifiers)
+	* addSign, if true, makes the function return a + in front of positive
+	  values (the default)
 
 	>>> degToDms(-3.24722, "", 0, True, True)
 	'-031449'
 	>>> degToDms(0)
 	'+0 00 00.00'
-	>>> degToDms(-0.25)
-	'-0 15 00.00'
+	>>> degToDms(0, addSign=False)
+	'0 00 00.00'
+	>>> degToDms(-0.25, sepChar=":")
+	'-0:15:00.00'
 	>>> degToDms(-23.50, secondFracs=4)
 	'-23 30 00.0000'
 	>>> "%.4f"%dmsToDeg(degToDms(-25.6835, sepChar=":"), sepChar=":")
 	'-25.6835'
 	"""
-	sign = '+'
-	if deg<0:
-		sign = "-"
-		deg = -deg
-	rest, degs = math.modf(deg)
-	rest, minutes = math.modf(rest*60)
-	if secondFracs==0:
-		secondFracs = -1
-	
-	if preserveLeading:
-		degFormat = "%s%02d"
-	else:
-		degFormat = "%s%d"
+	if truncate:
+		secondFracs += 8
 
-	return sepChar.join([
-		degFormat%(sign, int(degs)), 
-		"%02d"%abs(int(minutes)), 
-		_formatSecs(abs(rest*60), secondFracs, truncate)])
+	fmted = angle_formats.degrees_to_string(
+		deg, sep=(sepChar, sepChar), precision=secondFracs,
+		pad=preserveLeading)
+
+	if truncate:
+		fmted = fmted[:-8].rstrip(".")
+
+	if addSign and deg>=0:
+		fmted = "+"+fmted
+	
+	return fmted
 
 
 @codetricks.document
@@ -526,7 +518,7 @@ def makeIAUId(prefix, long, lat, longSec=0, latSec=0):
 
 
 def datetimeToRFC2616(dt):
-	"""returns a UTC datetime object in the format requried by http.
+	"""returns a UTC datetime object in the format required by http.
 
 	This may crap when you fuzz with the locale.  In general, when handling
 	"real" times within the DC, prefer unix timestamps over datetimes and
@@ -689,7 +681,7 @@ def formatISODT(dt):
 	For convenience, None is returned as None.
 
 	Also for convenience, you can pass in a string; this will then be parsed
-	first, which provides both some basic format validation and guranteed
+	first, which provides both some basic format validation and guaranteed
 	DALI-compliant serialisation.
 
 	>>> formatISODT(datetime.datetime(2015, 10, 20, 12, 34, 22, 250))
@@ -721,7 +713,7 @@ def formatFloat(f):
 	'0.333333'
 	>>> formatFloat(-1/3e20)
 	'-3.33333e-21'
-	>>> formatFloat(math.pi)
+	>>> import math;formatFloat(math.pi)
 	'3.14159'
 	>>> formatFloat(20000000.23)
 	'2e+07'
