@@ -96,7 +96,7 @@ def getNullvalue(field, validator, default=None):
 
 
 def unravelArray(arraysize, seq):
-	"""turns a flat sequence into an n-dim array as specfied by the votable
+	"""turns a flat sequence into an n-dim array as specified by the votable
 	arraysize spec arraysize.
 
 	arraysize is <int>{"x"<int>}*?|*.
@@ -132,7 +132,7 @@ def parseVOTableArraysizeEl(spec, fieldName):
 	This will accept single numbers (returns False, number),
 	number* (returns True, number) and just * (returns 0, number).
 
-	This is used to parse the last part of an ND array spec.  Everything
+	This is used to parse the last part of an n-d array spec.  Everything
 	before that must be an integer only.
 	"""
 	try:
@@ -166,7 +166,7 @@ def makeShapeValidator(field):
 		try:
 			stride = reduce(lambda a,b: a*b, [int(l) for l in dimensions[:-1]])
 		except ValueError:
-			raise common.VOTableError("Invalid arraysize '%s' specificed in"
+			raise common.VOTableError("Invalid arraysize '%s' specified in"
 				" field or param name '%s'"%(
 				field.arraysize, field.name))
 	
@@ -246,7 +246,7 @@ def trimString(val, arraysize, padChar=" "):
 
 	val can also be a sequence of strings (or nested more deeply).  In that
 	case, trimString will flatten the value(s), padding and cropping as
-	neccessary.
+	necessary.
 
 	If val is None, then as many padChars will be returned as arraysize
 	wants (which is 0 for variable-length fields).
