@@ -378,7 +378,7 @@ def getLength(arraysize):
 def getShape(datatype, arraysize):
 	"""returns a numpy-compatible shape for a VOTable arraysize.
 
-	For variable length 1D arrays, this returns None; for 2+D arrrays, the 
+	For variable length 1D arrays, this returns None; for 2+D arrays, the 
 	last dimension is currently replaced by 1.  Which doesn't sound smart.
 	"""
 	if arraysize is None:
