@@ -2,7 +2,7 @@
 Binary VOTable encoding.
 """
 
-#c Copyright 2008-2021, the GAVO project <gavo@ari.uni-heidelberg.de>
+#c Copyright 2008-2022, the GAVO project <gavo@ari.uni-heidelberg.de>
 #c
 #c This program is free software, covered by the GNU GPL.  See the
 #c COPYING file in the source distribution.
@@ -32,7 +32,7 @@ def _getArrayShapingCode(field, padder):
 	base = [
 		"if val is None: val = []"]
 	if field.isMultiDim():
-		# it's an nD array (n>1): flatten out all values
+		# it's an n-d array (n>1): flatten out all values
 		base.append("val = coding.ravel(val)")
 	if field.hasVarLength():
 		return base+["tokens.append(struct.pack('!i', len(val)))"]
@@ -94,7 +94,7 @@ def _makeBitEncoder(field, allowNULL=False):
 		"  while curByte:",
 		"    tmp.append(curByte)",
 		"    curByte, rest = rest%256, rest//256",
-		"  if not tmp:",   # make sure we leave somthing even for 0
+		"  if not tmp:",   # make sure we leave something even for 0
 		"    tmp.append(0)",
 		"  tmp.reverse()",])
 
@@ -102,7 +102,7 @@ def _makeBitEncoder(field, allowNULL=False):
 		if length is None:  # variable length: dump number of bits
 			src.extend([
 				"  tokens.append(struct.pack('!i', len(tmp)*8))"])
-		else:  # crop/expand as necesary
+		else:  # crop/expand as necessary
 			numBytes = int(length)//8+(not not int(length)%8)
 			src.extend([
 				"  if len(tmp)<%d: tmp = [0]*(%d-len(tmp))+tmp"%(
