@@ -423,7 +423,17 @@ class Request(server.Request):
 	  you're actually dealing with non-utf-8 data (and then you should
 	  probably use request.fields).
 	"""
-	fields = None
+	def __init__(self, *args, **kwargs):
+		server.Request.__init__(self, *args, **kwargs)
+		self.fields = None
+		self.finished = False
+		self.notifyFinish().addBoth(self._markFinished)
+	
+	def _markFinished(self, ignored):
+		# I'm adding a finished attribute for convenience so clients
+		# can avoid finishing requests that don't need that more
+		# easily.
+		self.finished = True
 
 	def gotLength(self, length):
 		server.Request.gotLength(self, length)
@@ -455,7 +465,7 @@ class Request(server.Request):
 				self.content, self, maxUploadSize)
 
 	def write(self, payload):
-		if getattr(self, "channel", None) is None:
+		if self.finished or getattr(self, "channel", None) is None:
 			# request processing should really have stopped when channel
 			# has gone away.  But regrettably there are code paths when
 			# that doesn't happen (in particular, we're a bit lazy when
