@@ -37,7 +37,7 @@ __docformat__ = "restructuredtext en"
 
 
 class RDBlocked(Exception):
-	"""is raised when a ResourceDescriptor is blocked due to maintanence
+	"""is raised when a ResourceDescriptor is blocked due to maintenance
 	and caught by the root resource..
 	"""
 
@@ -144,7 +144,7 @@ class GavoRenderMixin(common.CommonRenderers):
 	@template.renderer
 	def metahtml(self, request, tag):
 		"""replaces a meta key with an html rendering of the metadata in
-		the serivce.
+		the service.
 		"""
 		return self._doRenderMeta(request, tag)
 
@@ -729,7 +729,7 @@ class ServiceBasedPage(ResourceBasedPage):
 	def runSync(self, rawData):
 		"""calls the actual service.
 
-		This will run in the current thread; you will ususally
+		This will run in the current thread; you will usually
 		want to use runAsync from the main nevow event loop unless you know
 		the service is quick or actually works asynchronously.
 		"""
@@ -753,21 +753,25 @@ class ServiceBasedPage(ResourceBasedPage):
 		self.queryMeta["formal_data"] = rawData
 
 		# contextGrammar wants a dict of lists, whereas formal has direct
-		# values; accomodate to contextGrammar
+		# values; accommodate to contextGrammar
 
 		if (self.service.core.outputTable.columns and 
 				not self.service.getCurOutputFields(self.queryMeta)):
 			raise base.ValidationError("These output settings yield no"
 				" output fields", "_OUTPUT")
 
-		data = dict((k, [v]  if v is not None else None) 
-			for k,v in rawData.items())
+		data = {}
+		for k, v in rawData.items():
+			if v is None or isinstance(v, list):
+				data[k] = v
+			else:
+				data[k] = [v]
 		return self.runAsync(svcs.PreparsedInput(data))
 
 	def data_serviceURL(self, renderer):
 		"""returns a relative URL for this service using the renderer.
 
-		This is ususally used like this:
+		This is usually used like this:
 
 		<a><n:attr name="href" n:data="serviceURL info" n:render="data">x</a>
 		"""
