@@ -16,6 +16,7 @@ import urllib.parse
 from twisted.web import template
 from twisted.web.template import tags as T
 
+from gavo import base
 from gavo import formal
 from gavo import formats
 from gavo import rsc
@@ -56,6 +57,9 @@ def _productMapperFactory(colDesc):
 	else:
 		mouseoverHandler = "insertPreview(this, null)"
 	fixedArgs = ""
+	
+	baseURL = base.getCurrentServerURL()
+
 	def coder(val):
 		if val:
 			anchor = re.sub(r"\?.*", "", 
@@ -65,11 +69,12 @@ def _productMapperFactory(colDesc):
 
 			if isinstance(val, str) and utils.looksLikeURLPat.match(val):
 				# readily inserted URLs probably can't do previews, and
-				# we must not direct them through the product table anway.
+				# we must not direct them through the product table anyway.
 				return T.a(href=val)[anchor]
 
 			else:
-				return T.a(href=products.makeProductLink(val)+fixedArgs,
+				return T.a(
+					href=products.makeProductLink(val, useHost=baseURL)+fixedArgs,
 					onmouseover=mouseoverHandler,
 					class_="productlink")[anchor]
 		else:
