@@ -737,7 +737,7 @@ class ByAuthor(common.JSONQuery):
 class ServiceInfo(common.JSONQuery):
 	query = (
 		"SELECT title, description, authors,"
-		"    case when dateUpdated is null then 'unknown'"
+		"    case when dateUpdated is null then 'N/A'"
 		"       else to_char(dateUpdated, 'YYYY-MM-DD') end as lastupdate,"
 		"    referenceURL, accessURL"
 		"  FROM dc.interfaces"
@@ -746,6 +746,18 @@ class ServiceInfo(common.JSONQuery):
 		"  WHERE setname='local'"
 		"  AND resId=%(resId)s and sourceRd=%(sourceRD)s")
 
+	def doQuery(self, queryArgs):
+		res = super().doQuery(queryArgs)
+		for rec in res:
+			try:
+				rec["description"] = utils.rstxToHTML(
+					(rec["description"] or "").strip())
+			except Exception:
+				# well, perhaps it's no RST.  Whatever it is, don't fail
+				# but show what you have.
+				pass
+		return res
+
 
 ROOT_PAGE_HELPERS = resource.Resource()
 ROOT_PAGE_HELPERS.putChild(b"titles", Titles())
