@@ -784,7 +784,7 @@ class RDInfoPage(grend.CustomTemplateMixin, grend.ResourceBasedPage):
 		adqlNote = ""
 		if tableDef.adql:
 			adqlNote = T.span(class_="adqlnote")[" ",
-				"–", " queriable through ",
+				"–", " queryable through ",
 				T.a(href="/tap")["TAP"], " and ", 
 				T.a(href="/adql")["ADQL"],
 				" "]
