@@ -619,7 +619,7 @@ class APIRenderer(UnifiedDALRenderer):
 	evaluate basic DALI parameters.  You can declare that by
 	including <FEED source="//pql#DALIPars"/> in your service.
 
-	These will return basic serice metadata if passed MAXREC=0.
+	These will return basic service metadata if passed MAXREC=0.
 	"""
 	name = "api"
 	parameterStyle = "dali"
@@ -823,7 +823,7 @@ def _doDatalinkXSLT(data, _cache={}):
 	apparently suck.
 
 	Remove this once we've worked out how to make the datalink-to-xml 
-	stylesheet compatible with actual browers.
+	stylesheet compatible with actual browsers.
 	"""
 	if "etree" not in _cache:
 		from lxml import etree as lxmletree
